@@ -849,7 +849,7 @@ sub  MODIFY_CODE_ATTRIBUTES
     my @reject;
     foreach my $attr( @attrs )
     {
-        if( $attr !~ /^ (SIGNAL|SLOT|DCOP) \(( .* )\) $/x )
+        if( $attr !~ /^ (TQ_SIGNAL|TQ_SLOT|DCOP) \(( .* )\) $/x )
         {
              push @reject, $attr;
              next;
@@ -877,7 +877,7 @@ require Exporter;
 
 our $VERSION = '3.008';
 
-our @EXPORT = qw(&TQT_SIGNAL &TQT_SLOT &CAST &emit &min &max);
+our @EXPORT = qw(&TQ_SIGNAL &TQ_SLOT &CAST &emit &min &max);
 
 XSLoader::load 'TQt', $VERSION;
 
@@ -891,8 +891,8 @@ TQt::_internal::init();
 # In general, I'm not a fan of prototypes.
 # However, I'm also not a fan of parentheses
 
-sub TQT_SIGNAL ($) { '2' . $_[0] }
-sub TQT_SLOT ($) { '1' . $_[0] }
+sub TQ_SIGNAL ($) { '2' . $_[0] }
+sub TQ_SLOT ($) { '1' . $_[0] }
 sub CAST ($$) { bless $_[0], " $_[1]" }
 sub emit (@) { pop @_ }
 sub min ($$) { $_[0] < $_[1] ? $_[0] : $_[1] }
