@@ -9,7 +9,7 @@ my $quit = TQt::PushButton("Quit", undef);
 $quit->resize(75, 30);
 $quit->setFont(TQt::Font("Times", 18, &TQt::Font::Bold));
 
-$a->connect($quit, TQT_SIGNAL('clicked()'), TQT_SLOT('quit()'));
+$a->connect($quit, TQ_SIGNAL('clicked()'), TQ_SLOT('quit()'));
 
 $a->setMainWidget($quit);
 $quit->show;
