@@ -97,7 +97,7 @@ bool MasEngine::init()
     }
     m_inited=true;              // we connected to MAS
 
-    connect ( m_pPlayingTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( playingTimeout() ) );
+    connect ( m_pPlayingTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( playingTimeout() ) );
 
     emit statusText( "MAS Engine inited :-)");
     return true;
