@@ -33,7 +33,7 @@
 #include <tqinputdialog.h>
 #include <tqregexp.h>
 
-//KDE includes
+//TDE includes
 #include <tdelocale.h>
 #include <kstandarddirs.h>
 #include <tdepopupmenu.h>
@@ -146,37 +146,37 @@ void CMainIndex::initView() {
 	m_popup = new TDEPopupMenu(viewport());
 	m_popup->insertTitle(i18n("Bookshelf"));
 
-	m_actions.newFolder = new TDEAction(i18n("Create a new folder"), CResMgr::mainIndex::newFolder::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(createNewFolder()), TQT_TQOBJECT(this));
-	m_actions.changeFolder = new TDEAction(i18n("Change this folder"),CResMgr::mainIndex::changeFolder::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(changeFolder()), TQT_TQOBJECT(this));
+	m_actions.newFolder = new TDEAction(i18n("Create a new folder"), CResMgr::mainIndex::newFolder::icon, 0, this, TQ_SLOT(createNewFolder()), this);
+	m_actions.changeFolder = new TDEAction(i18n("Change this folder"),CResMgr::mainIndex::changeFolder::icon, 0, this, TQ_SLOT(changeFolder()), this);
 
-	m_actions.changeBookmark = new TDEAction(i18n("Change bookmark description"),CResMgr::mainIndex::changeBookmark::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(changeBookmark()), TQT_TQOBJECT(this));
-	m_actions.importBookmarks = new TDEAction(i18n("Import bookmarks"),CResMgr::mainIndex::importBookmarks::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(importBookmarks()), TQT_TQOBJECT(this));
-	m_actions.exportBookmarks = new TDEAction(i18n("Export bookmarks"),CResMgr::mainIndex::exportBookmarks::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(exportBookmarks()), TQT_TQOBJECT(this));
-	m_actions.printBookmarks = new TDEAction(i18n("Print bookmarks"),CResMgr::mainIndex::printBookmarks::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(printBookmarks()), TQT_TQOBJECT(this));
+	m_actions.changeBookmark = new TDEAction(i18n("Change bookmark description"),CResMgr::mainIndex::changeBookmark::icon, 0, this, TQ_SLOT(changeBookmark()), this);
+	m_actions.importBookmarks = new TDEAction(i18n("Import bookmarks"),CResMgr::mainIndex::importBookmarks::icon, 0, this, TQ_SLOT(importBookmarks()), this);
+	m_actions.exportBookmarks = new TDEAction(i18n("Export bookmarks"),CResMgr::mainIndex::exportBookmarks::icon, 0, this, TQ_SLOT(exportBookmarks()), this);
+	m_actions.printBookmarks = new TDEAction(i18n("Print bookmarks"),CResMgr::mainIndex::printBookmarks::icon, 0, this, TQ_SLOT(printBookmarks()), this);
 
-	m_actions.deleteEntries = new TDEAction(i18n("Remove selected item(s)"),CResMgr::mainIndex::deleteItems::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(deleteEntries()), TQT_TQOBJECT(this));
+	m_actions.deleteEntries = new TDEAction(i18n("Remove selected item(s)"),CResMgr::mainIndex::deleteItems::icon, 0, this, TQ_SLOT(deleteEntries()), this);
 
-	m_actions.editModuleMenu = new TDEActionMenu(i18n("Edit this work"),CResMgr::mainIndex::editModuleMenu::icon, TQT_TQOBJECT(this));
+	m_actions.editModuleMenu = new TDEActionMenu(i18n("Edit this work"),CResMgr::mainIndex::editModuleMenu::icon, this);
 	m_actions.editModuleMenu->setDelayed(false);
-	m_actions.editModulePlain = new TDEAction(i18n("Plain text"),CResMgr::mainIndex::editModulePlain::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(editModulePlain()), TQT_TQOBJECT(this));
-	m_actions.editModuleHTML = new TDEAction(i18n("HTML"),CResMgr::mainIndex::editModuleHTML::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(editModuleHTML()), TQT_TQOBJECT(this));
+	m_actions.editModulePlain = new TDEAction(i18n("Plain text"),CResMgr::mainIndex::editModulePlain::icon, 0, this, TQ_SLOT(editModulePlain()), this);
+	m_actions.editModuleHTML = new TDEAction(i18n("HTML"),CResMgr::mainIndex::editModuleHTML::icon, 0, this, TQ_SLOT(editModuleHTML()), this);
 	
-	m_actions.searchInModules = new TDEAction(i18n("Search in selected work(s)"),CResMgr::mainIndex::search::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(searchInModules()), TQT_TQOBJECT(this));
-	m_actions.unlockModule = new TDEAction(i18n("Unlock this work"),CResMgr::mainIndex::unlockModule::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(unlockModule()), TQT_TQOBJECT(this));
-	m_actions.aboutModule = new TDEAction(i18n("About this work"),CResMgr::mainIndex::aboutModule::icon, 0, TQT_TQOBJECT(this), TQT_SLOT(aboutModule()), TQT_TQOBJECT(this));
+	m_actions.searchInModules = new TDEAction(i18n("Search in selected work(s)"),CResMgr::mainIndex::search::icon, 0, this, TQ_SLOT(searchInModules()), this);
+	m_actions.unlockModule = new TDEAction(i18n("Unlock this work"),CResMgr::mainIndex::unlockModule::icon, 0, this, TQ_SLOT(unlockModule()), this);
+	m_actions.aboutModule = new TDEAction(i18n("About this work"),CResMgr::mainIndex::aboutModule::icon, 0, this, TQ_SLOT(aboutModule()), this);
 
 
 	//fill the popup menu itself
 	m_actions.newFolder->plug(m_popup);
 	m_actions.changeFolder->plug(m_popup);
-	(new TDEActionSeparator(TQT_TQOBJECT(this)))->plug(m_popup);
+	(new TDEActionSeparator(this))->plug(m_popup);
 	m_actions.changeBookmark->plug(m_popup);
 	m_actions.importBookmarks->plug(m_popup);
 	m_actions.exportBookmarks->plug(m_popup);
 	m_actions.printBookmarks->plug(m_popup);
-	(new TDEActionSeparator(TQT_TQOBJECT(this)))->plug(m_popup);
+	(new TDEActionSeparator(this))->plug(m_popup);
 	m_actions.deleteEntries->plug(m_popup);
-	(new TDEActionSeparator(TQT_TQOBJECT(this)))->plug(m_popup);
+	(new TDEActionSeparator(this))->plug(m_popup);
 	m_actions.editModuleMenu->plug(m_popup);
 	//sub item of edit module menu
 	m_actions.editModuleMenu->insert(m_actions.editModulePlain); 
@@ -188,16 +188,16 @@ void CMainIndex::initView() {
 	m_actions.aboutModule->plug(m_popup);
 }
 
-/** Initialize the SIGNAL<->TQT_SLOT connections */
+/** Initialize the signal<->slot connections */
 void CMainIndex::initConnections() {
-	connect(this, TQT_SIGNAL(executed(TQListViewItem*)),
-			TQT_SLOT(slotExecuted(TQListViewItem*)));
-	connect(this, TQT_SIGNAL(dropped(TQDropEvent*, TQListViewItem*, TQListViewItem*)),
-			TQT_SLOT(dropped(TQDropEvent*, TQListViewItem*, TQListViewItem*)));
-	connect(this, TQT_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)),
-			TQT_SLOT(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)));
-	connect(&m_autoOpenTimer, TQT_SIGNAL(timeout()),
-			this, TQT_SLOT(autoOpenTimeout()));
+	connect(this, TQ_SIGNAL(executed(TQListViewItem*)),
+			TQ_SLOT(slotExecuted(TQListViewItem*)));
+	connect(this, TQ_SIGNAL(dropped(TQDropEvent*, TQListViewItem*, TQListViewItem*)),
+			TQ_SLOT(dropped(TQDropEvent*, TQListViewItem*, TQListViewItem*)));
+	connect(this, TQ_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)),
+			TQ_SLOT(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)));
+	connect(&m_autoOpenTimer, TQ_SIGNAL(timeout()),
+			this, TQ_SLOT(autoOpenTimeout()));
 }
 
 /** Is called when an item was clicked/double clicked. */
@@ -300,7 +300,7 @@ void CMainIndex::dropped( TQDropEvent* e, TQListViewItem* parent, TQListViewItem
 
 	if (afterItem && afterItem->isFolder()) {
 		moveSelectedItems = false;
-		removeSelectedItems = false; //why TRUE?
+		removeSelectedItems = false;
 
 		afterItem->setOpen(true);
 		afterItem->dropped(e); //inserts new items, moving only works on the same level
@@ -520,7 +520,7 @@ void CMainIndex::printBookmarks() {
 	}
 
 	util::scoped_ptr<CPrinter> printer( 
-		new CPrinter( TQT_TQOBJECT(this), CBTConfig::getDisplayOptionDefaults(), CBTConfig::getFilterOptionDefaults() ) 
+		new CPrinter( this, CBTConfig::getDisplayOptionDefaults(), CBTConfig::getFilterOptionDefaults() ) 
 	);
 	printer->printKeyTree(tree);
 }
