@@ -545,7 +545,7 @@ KisImage::KisImage(const KisImage& rhs) : TQObject(), TDEShared(rhs)
         TQ_CHECK_PTR(m_bkg);
 
         m_rootLayer = static_cast<KisGroupLayer*>(rhs.m_rootLayer->clone().data());
-        connect(m_rootLayer, TQT_SIGNAL(sigDirty(TQRect)), this, TQT_SIGNAL(sigImageUpdated(TQRect)));
+        connect(m_rootLayer, TQ_SIGNAL(sigDirty(TQRect)), this, TQ_SIGNAL(sigImageUpdated(TQRect)));
             
         m_annotations = rhs.m_annotations; // XXX the annotations would probably need to be deep-copied
 
@@ -663,7 +663,7 @@ void KisImage::init(KisUndoAdapter *adapter, TQ_INT32 width, TQ_INT32 height,  K
     m_bkg = new KisBackground();
 
     m_rootLayer = new KisGroupLayer(this,"root", OPACITY_OPAQUE);
-    connect(m_rootLayer, TQT_SIGNAL(sigDirty(TQRect)), this, TQT_SIGNAL(sigImageUpdated(TQRect)));
+    connect(m_rootLayer, TQ_SIGNAL(sigDirty(TQRect)), this, TQ_SIGNAL(sigImageUpdated(TQRect)));
 
     m_xres = 1.0;
     m_yres = 1.0;
@@ -681,7 +681,7 @@ bool KisImage::locked() const
 void KisImage::lock()
 {
     if (!locked()) {
-        if (m_rootLayer) disconnect(m_rootLayer, TQT_SIGNAL(sigDirty(TQRect)), this, TQT_SIGNAL(sigImageUpdated(TQRect)));
+        if (m_rootLayer) disconnect(m_rootLayer, TQ_SIGNAL(sigDirty(TQRect)), this, TQ_SIGNAL(sigImageUpdated(TQRect)));
         m_private->sizeChangedWhileLocked = false;
         m_private->selectionChangedWhileLocked = false;
     }
@@ -707,7 +707,7 @@ void KisImage::unlock()
                 emit sigActiveSelectionChanged(this);
             }
 
-            if (m_rootLayer) connect(m_rootLayer, TQT_SIGNAL(sigDirty(TQRect)), this, TQT_SIGNAL(sigImageUpdated(TQRect)));
+            if (m_rootLayer) connect(m_rootLayer, TQ_SIGNAL(sigDirty(TQRect)), this, TQ_SIGNAL(sigImageUpdated(TQRect)));
         }
     }
 }
@@ -1139,7 +1139,7 @@ bool KisImage::addLayer(KisLayerSP layer, KisGroupLayerSP parent, KisLayerSP abo
                 actions.at(i)->act(player.data()->paintDevice(), width(), height());
             }
 
-            connect(player, TQT_SIGNAL(sigMaskInfoChanged()), this, TQT_SIGNAL(sigMaskInfoChanged()));
+            connect(player, TQ_SIGNAL(sigMaskInfoChanged()), this, TQ_SIGNAL(sigMaskInfoChanged()));
         }
 
         if (layer->extent().isValid()) layer->setDirty();
@@ -1181,8 +1181,8 @@ bool KisImage::removeLayer(KisLayerSP layer)
         }
         KisPaintLayerSP player = dynamic_cast<KisPaintLayer*>(layer.data());
         if (player != 0) {
-            disconnect(player, TQT_SIGNAL(sigMaskInfoChanged()),
-                       this, TQT_SIGNAL(sigMaskInfoChanged()));
+            disconnect(player, TQ_SIGNAL(sigMaskInfoChanged()),
+                       this, TQ_SIGNAL(sigMaskInfoChanged()));
         }
         KisLayerSP l = layer->prevSibling();
         TQRect r = layer->extent();
@@ -1307,7 +1307,7 @@ TQ_INT32 KisImage::nHiddenLayers() const
 void KisImage::flatten()
 {
     KisGroupLayerSP oldRootLayer = m_rootLayer;
-    disconnect(oldRootLayer, TQT_SIGNAL(sigDirty(TQRect)), this, TQT_SIGNAL(sigImageUpdated(TQRect)));
+    disconnect(oldRootLayer, TQ_SIGNAL(sigDirty(TQRect)), this, TQ_SIGNAL(sigImageUpdated(TQRect)));
 
     KisPaintLayer *dst = new KisPaintLayer(this, nextLayerName(), OPACITY_OPAQUE, colorSpace());
     TQ_CHECK_PTR(dst);
@@ -1318,7 +1318,7 @@ void KisImage::flatten()
     gc.bitBlt(rc.x(), rc.y(), COMPOSITE_COPY, mergedImage(), OPACITY_OPAQUE, rc.left(), rc.top(), rc.width(), rc.height());
 
     m_rootLayer = new KisGroupLayer(this, "", OPACITY_OPAQUE);
-    connect(m_rootLayer, TQT_SIGNAL(sigDirty(TQRect)), this, TQT_SIGNAL(sigImageUpdated(TQRect)));
+    connect(m_rootLayer, TQ_SIGNAL(sigDirty(TQRect)), this, TQ_SIGNAL(sigImageUpdated(TQRect)));
 
     if (undo()) {
         m_adapter->beginMacro(i18n("Flatten Image"));
@@ -1619,12 +1619,12 @@ void KisImage::setColorSpace(KisColorSpace * colorSpace)
 
 void KisImage::setRootLayer(KisGroupLayerSP rootLayer)
 {
-    disconnect(m_rootLayer, TQT_SIGNAL(sigDirty(TQRect)), this, TQT_SIGNAL(sigImageUpdated(TQRect)));
+    disconnect(m_rootLayer, TQ_SIGNAL(sigDirty(TQRect)), this, TQ_SIGNAL(sigImageUpdated(TQRect)));
 
     m_rootLayer = rootLayer;
 
     if (!locked()) {
-        connect(m_rootLayer, TQT_SIGNAL(sigDirty(TQRect)), this, TQT_SIGNAL(sigImageUpdated(TQRect)));
+        connect(m_rootLayer, TQ_SIGNAL(sigDirty(TQRect)), this, TQ_SIGNAL(sigImageUpdated(TQRect)));
     }
     activate(m_rootLayer->firstChild());
 }
