@@ -4,7 +4,7 @@ iconName = 'designer'
 helpText = """TQt provides a rich set of widgets for application use.  
 Select the children of this item to see for yourself."""
 
-from PyTQt.tqt import TQFrame, TQVBoxLayout, SIGNAL
+from PyTQt.tqt import TQFrame, TQVBoxLayout, TQ_SIGNAL
 from tdeui import KTextEdit
 
 
