@@ -14,8 +14,8 @@
 #include <config.h>
 #endif 
 
-#include <ntqdialog.h>
-#include <ntqstring.h>
+#include <tqdialog.h>
+#include <tqstring.h>
 
 class TQLabel;
 
