@@ -88,7 +88,7 @@ KexiDataSourcePage::KexiDataSourcePage(TQWidget *parent, const char *name)
 	m_clearWidgetDSButton->setMinimumHeight(m_widgetDSLabel->minimumHeight());
 	TQToolTip::add(m_clearWidgetDSButton, i18n("Clear widget's data source"));
 	hlyr->addWidget(m_clearWidgetDSButton);
-	connect(m_clearWidgetDSButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(clearWidgetDataSourceSelection()));
+	connect(m_clearWidgetDSButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(clearWidgetDataSourceSelection()));
 
 	m_sourceFieldCombo = new KexiFieldComboBox(contents, "sourceFieldCombo");
 	m_widgetDSLabel->setBuddy(m_sourceFieldCombo);
@@ -114,13 +114,13 @@ KexiDataSourcePage::KexiDataSourcePage(TQWidget *parent, const char *name)
 	m_gotoButton->setMinimumHeight(m_dataSourceLabel->minimumHeight());
 	TQToolTip::add(m_gotoButton, i18n("Go to selected form's data source"));
 	hlyr->addWidget(m_gotoButton);
-	connect(m_gotoButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotGotoSelected()));
+	connect(m_gotoButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotGotoSelected()));
 
 	m_clearDSButton = new KexiSmallToolButton(contents, TQString(), "clear_left", "clearDSButton");
 	m_clearDSButton->setMinimumHeight(m_dataSourceLabel->minimumHeight());
 	TQToolTip::add(m_clearDSButton, i18n("Clear form's data source"));
 	hlyr->addWidget(m_clearDSButton);
-	connect(m_clearDSButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(clearDataSourceSelection()));
+	connect(m_clearDSButton, TQ_SIGNAL(clicked()), this, TQ_SLOT(clearDataSourceSelection()));
 
 	m_dataSourceCombo = new KexiDataSourceComboBox(contents, "dataSourceCombo");
 	m_dataSourceLabel->setBuddy(m_dataSourceCombo);
@@ -179,23 +179,23 @@ KexiDataSourcePage::KexiDataSourcePage(TQWidget *parent, const char *name)
 	m_addField->setFocusPolicy(TQWidget::StrongFocus);
 	TQToolTip::add(m_addField, i18n("Insert selected fields into form"));
 	hlyr->addWidget(m_addField);
-	connect(m_addField, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotInsertSelectedFields()));
+	connect(m_addField, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotInsertSelectedFields()));
 
 	m_fieldListView = new KexiFieldListView(contents, "fieldListView",
 		KexiFieldListView::ShowDataTypes | KexiFieldListView::AllowMultiSelection );
 	m_fieldListView->setSizePolicy(TQSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Expanding));
 	m_availableFieldsLabel->setBuddy(m_fieldListView);
 	contentsVlyr->addWidget(m_fieldListView, 1);
-	connect(m_fieldListView, TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(slotFieldListViewSelectionChanged()));
-	connect(m_fieldListView, TQT_SIGNAL(fieldDoubleClicked(const TQString&, const TQString&, const TQString&)),
-		this, TQT_SLOT(slotFieldDoubleClicked(const TQString&, const TQString&, const TQString&)));
+	connect(m_fieldListView, TQ_SIGNAL(selectionChanged()), this, TQ_SLOT(slotFieldListViewSelectionChanged()));
+	connect(m_fieldListView, TQ_SIGNAL(fieldDoubleClicked(const TQString&, const TQString&, const TQString&)),
+		this, TQ_SLOT(slotFieldDoubleClicked(const TQString&, const TQString&, const TQString&)));
 #endif
 
 	vlyr->addStretch(1);
 
-	connect(m_dataSourceCombo, TQT_SIGNAL(textChanged(const TQString &)), this, TQT_SLOT(slotDataSourceTextChanged(const TQString &)));
-	connect(m_dataSourceCombo, TQT_SIGNAL(dataSourceChanged()), this, TQT_SLOT(slotDataSourceChanged()));
-	connect(m_sourceFieldCombo, TQT_SIGNAL(selected()), this, TQT_SLOT(slotFieldSelected()));
+	connect(m_dataSourceCombo, TQ_SIGNAL(textChanged(const TQString &)), this, TQ_SLOT(slotDataSourceTextChanged(const TQString &)));
+	connect(m_dataSourceCombo, TQ_SIGNAL(dataSourceChanged()), this, TQ_SLOT(slotDataSourceChanged()));
+	connect(m_sourceFieldCombo, TQ_SIGNAL(selected()), this, TQ_SLOT(slotFieldSelected()));
 
 	clearDataSourceSelection();
 	slotFieldListViewSelectionChanged();
