@@ -88,8 +88,8 @@ KioskGui::KioskGui()
 
     m_view->pbHelp->hide(); // TODO, write help :)
 
-    connect(m_view->pbDiscard, TQT_SIGNAL(clicked()), this, TQT_SLOT(discardPage()));
-    connect(m_view->pbFinished, TQT_SIGNAL(clicked()), this, TQT_SLOT(finishedPage()));
+    connect(m_view->pbDiscard, TQ_SIGNAL(clicked()), this, TQ_SLOT(discardPage()));
+    connect(m_view->pbFinished, TQ_SIGNAL(clicked()), this, TQ_SLOT(finishedPage()));
 
     TDEConfig *config = kapp->config();
     config->setGroup("General");
@@ -98,7 +98,7 @@ KioskGui::KioskGui()
 
     selectPage(PAGE_PROFILE_SELECTION, true);
     
-    TQTimer::singleShot(0, this, TQT_SLOT(slotCheckEtcSkel()));
+    TQTimer::singleShot(0, this, TQ_SLOT(slotCheckEtcSkel()));
 }
 
 KioskGui::~KioskGui()
@@ -140,7 +140,7 @@ void KioskGui::setWidgetBackground(TQWidget *w)
     for(TQWidget *wid=0; (wid = (TQWidget*)it.current()); ++it)
     {
         wid->setBackgroundOrigin(WindowOrigin);
-        if (::tqqt_cast<TQPushButton*>(wid))
+        if (::tqt_cast<TQPushButton*>(wid))
            wid->setAutoMask(true);
     }
     w->setBackgroundOrigin(WindowOrigin);
@@ -154,21 +154,21 @@ void KioskGui::setSubCaption(const TQString &subCaption)
 
 void KioskGui::setupActions()
 {
-//    KStdAction::open(this, TQT_SLOT(fileOpen()), actionCollection());
-//    KStdAction::save(this, TQT_SLOT(fileSave()), actionCollection());
-//    KStdAction::saveAs(this, TQT_SLOT(fileSaveAs()), actionCollection());
-    KStdAction::quit(this, TQT_SLOT(close()), actionCollection());
-//    KStdAction::back(this, TQT_SLOT(previousPage()), actionCollection(), "previousPage");
-//    KStdAction::forward(this, TQT_SLOT(nextPage()), actionCollection(), "nextPage");
+//    KStdAction::open(this, TQ_SLOT(fileOpen()), actionCollection());
+//    KStdAction::save(this, TQ_SLOT(fileSave()), actionCollection());
+//    KStdAction::saveAs(this, TQ_SLOT(fileSaveAs()), actionCollection());
+    KStdAction::quit(this, TQ_SLOT(close()), actionCollection());
+//    KStdAction::back(this, TQ_SLOT(previousPage()), actionCollection(), "previousPage");
+//    KStdAction::forward(this, TQ_SLOT(nextPage()), actionCollection(), "nextPage");
 
 //    createStandardStatusBarAction();
 //    setStandardToolBarMenuEnabled(true);
 
-//    KStdAction::keyBindings(this, TQT_SLOT(optionsConfigureKeys()), actionCollection());
-//    KStdAction::configureToolbars(this, TQT_SLOT(optionsConfigureToolbars()), actionCollection());
-    KStdAction::preferences(this, TQT_SLOT(slotConfig()), actionCollection());
-    m_uploadAction = new TDEAction(i18n("Upload &All Profiles"), TQString(), 0, this, TQT_SLOT(uploadAllProfiles()), actionCollection(), "upload_all");
-    m_backgroundAction = new TDEToggleAction(i18n("Background Graphics"), TQString(), 0, this, TQT_SLOT(slotUpdateBackground()), actionCollection(), "show_background");
+//    KStdAction::keyBindings(this, TQ_SLOT(optionsConfigureKeys()), actionCollection());
+//    KStdAction::configureToolbars(this, TQ_SLOT(optionsConfigureToolbars()), actionCollection());
+    KStdAction::preferences(this, TQ_SLOT(slotConfig()), actionCollection());
+    m_uploadAction = new TDEAction(i18n("Upload &All Profiles"), TQString(), 0, this, TQ_SLOT(uploadAllProfiles()), actionCollection(), "upload_all");
+    m_backgroundAction = new TDEToggleAction(i18n("Background Graphics"), TQString(), 0, this, TQ_SLOT(slotUpdateBackground()), actionCollection(), "show_background");
 
     updateActions();
 }
@@ -277,21 +277,21 @@ void KioskGui::selectPage(int page, bool save)
        setWidgetBackground(m_profileSelectionPage);
 
        connect(m_profileSelectionPage->listProfile,
-               TQT_SIGNAL(contextMenuRequested(TQListViewItem *, const TQPoint &, int)),
-               this, TQT_SLOT(slotProfileContextMenu(TQListViewItem *, const TQPoint &)));
+               TQ_SIGNAL(contextMenuRequested(TQListViewItem *, const TQPoint &, int)),
+               this, TQ_SLOT(slotProfileContextMenu(TQListViewItem *, const TQPoint &)));
        connect(m_profileSelectionPage->listProfile,
-               TQT_SIGNAL(doubleClicked (TQListViewItem *, const TQPoint &, int )),
-               this, TQT_SLOT(nextPage()));
-       connect(m_profileSelectionPage->buttonDelete, TQT_SIGNAL(clicked()),
-               this, TQT_SLOT(slotDeleteProfile()));
-       connect(m_profileSelectionPage->buttonAdd, TQT_SIGNAL(clicked()),
-               this, TQT_SLOT(slotAddProfile()));
-       connect(m_profileSelectionPage->buttonProperty, TQT_SIGNAL(clicked()),
-               this, TQT_SLOT(slotProfileProperties()));
-       connect(m_profileSelectionPage->buttonSetup, TQT_SIGNAL(clicked()),
-               this, TQT_SLOT(slotProfileSetup()));
-       connect(m_profileSelectionPage->buttonUsers, TQT_SIGNAL(clicked()),
-               this, TQT_SLOT(slotManageUsers()));
+               TQ_SIGNAL(doubleClicked (TQListViewItem *, const TQPoint &, int )),
+               this, TQ_SLOT(nextPage()));
+       connect(m_profileSelectionPage->buttonDelete, TQ_SIGNAL(clicked()),
+               this, TQ_SLOT(slotDeleteProfile()));
+       connect(m_profileSelectionPage->buttonAdd, TQ_SIGNAL(clicked()),
+               this, TQ_SLOT(slotAddProfile()));
+       connect(m_profileSelectionPage->buttonProperty, TQ_SIGNAL(clicked()),
+               this, TQ_SLOT(slotProfileProperties()));
+       connect(m_profileSelectionPage->buttonSetup, TQ_SIGNAL(clicked()),
+               this, TQ_SLOT(slotProfileSetup()));
+       connect(m_profileSelectionPage->buttonUsers, TQ_SIGNAL(clicked()),
+               this, TQ_SLOT(slotManageUsers()));
 
        m_view->widgetStack->addWidget(m_profileSelectionPage, PAGE_PROFILE_SELECTION);
        m_profileSelectionPage->listProfile->setFocus();
@@ -305,7 +305,7 @@ void KioskGui::selectPage(int page, bool save)
        }
 
        m_componentSelectionPage = new ComponentSelectionPage(m_data, this);
-       connect(m_componentSelectionPage, TQT_SIGNAL(componentActivated()), this, TQT_SLOT(nextPage()));
+       connect(m_componentSelectionPage, TQ_SIGNAL(componentActivated()), this, TQ_SLOT(nextPage()));
        m_componentSelectionPage->setCurrentComponent(m_component);
        setWidgetBackground(m_componentSelectionPage);
 
