@@ -21,7 +21,7 @@
 #include <tdemessagebox.h>
 #include <tdeapplication.h>
 
-// qt includes
+// TQt includes
 #include <tqlayout.h>
 #include <tqcheckbox.h>
 #include <tqtabwidget.h>
@@ -84,23 +84,23 @@ KMFRuleEditorProtocol::KMFRuleEditorProtocol( TQWidget *parent, const char *name
 	cb_icmp_type->insertItem( "required-option-missing" );
 
 	mpwid = new KMFMultiPortWidget( tab_multiport, "mpwid" );
-	connect( mpwid, TQT_SIGNAL( sigMultiPortChanged( bool ) ), this, TQT_SLOT( toggleMultiPort( bool ) ) );
+	connect( mpwid, TQ_SIGNAL( sigMultiPortChanged( bool ) ), this, TQ_SLOT( toggleMultiPort( bool ) ) );
 
 	pw_dest_port = new KMFPortWidget( tab_ports, "pw_dest_port" );
 	pw_dest_port->setEnabled( false );
-	connect( c_dest_port, TQT_SIGNAL( toggled( bool ) ) , pw_dest_port, TQT_SLOT( setEnabled( bool ) ) );
+	connect( c_dest_port, TQ_SIGNAL( toggled( bool ) ) , pw_dest_port, TQ_SLOT( setEnabled( bool ) ) );
 
 	pw_src_port = new KMFPortWidget( tab_ports, "pw_src_port" );
 	pw_src_port->setEnabled( false );
-	connect( c_src_port, TQT_SIGNAL( toggled( bool ) ) , pw_src_port, TQT_SLOT( setEnabled( bool ) ) );
+	connect( c_src_port, TQ_SIGNAL( toggled( bool ) ) , pw_src_port, TQ_SLOT( setEnabled( bool ) ) );
 
 	tab_multiportLayout->addMultiCellWidget( mpwid, 0, 0, 2, 2 );
 	tab_portsLayout->addWidget( pw_src_port, 1, 1 );
 	tab_portsLayout->addWidget( pw_dest_port, 2, 1 );
 
-	connect( c_udp, TQT_SIGNAL( toggled( bool ) ), this, TQT_SLOT( toggleUdpRule( bool ) ) );
-	connect( c_icmp, TQT_SIGNAL( toggled( bool ) ), this, TQT_SLOT( toggleIcmpRule( bool ) ) );
-	connect( c_tcp, TQT_SIGNAL( toggled( bool ) ), this, TQT_SLOT( toggleTcpRule( bool ) ) );
+	connect( c_udp, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( toggleUdpRule( bool ) ) );
+	connect( c_icmp, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( toggleIcmpRule( bool ) ) );
+	connect( c_tcp, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( toggleTcpRule( bool ) ) );
 	tabWidget->setTabEnabled( tab_ports, false );
 	tabWidget->setTabEnabled( tab_multiport, false );
 	tabWidget->setTabEnabled( tab_icmp, false );
