@@ -96,7 +96,7 @@ IRCView::IRCView(TQWidget* parent, Server* newServer) : KTextBrowser(parent)
     setFocusPolicy(TQWidget::ClickFocus);
 
     // set basic style sheet for <p> to make paragraph spacing possible
-    TQStyleSheet* sheet=new TQStyleSheet(TQT_TQOBJECT(this),"ircview_style_sheet");
+    TQStyleSheet* sheet=new TQStyleSheet(this,"ircview_style_sheet");
     new TQStyleSheetItem(sheet,"p");
     setStyleSheet(sheet);
 
@@ -120,7 +120,7 @@ IRCView::IRCView(TQWidget* parent, Server* newServer) : KTextBrowser(parent)
 
     if (Preferences::useParagraphSpacing()) enableParagraphSpacing();
 
-    connect(this, TQT_SIGNAL(highlighted(const TQString&)), this, TQT_SLOT(highlightedSlot(const TQString&)));
+    connect(this, TQ_SIGNAL(highlighted(const TQString&)), this, TQ_SLOT(highlightedSlot(const TQString&)));
 }
 
 IRCView::~IRCView()
@@ -1190,7 +1190,7 @@ void IRCView::paintEvent(TQPaintEvent* event)
 
 void IRCView::contentsMouseReleaseEvent(TQMouseEvent *ev)
 {
-    if (ev->button() == Qt::MidButton)
+    if (ev->button() == TQt::MidButton)
     {
         if(m_copyUrlMenu)
         {
@@ -1204,11 +1204,11 @@ void IRCView::contentsMouseReleaseEvent(TQMouseEvent *ev)
         }
     }
 
-    if (ev->button() == Qt::LeftButton)
+    if (ev->button() == TQt::LeftButton)
     {
         if (m_mousePressed)
         {
-            if (ev->state() == (Qt::LeftButton|TQt::ShiftButton))
+            if (ev->state() == (TQt::LeftButton|TQt::ShiftButton))
                 saveLinkAs(m_highlightedURL);
             else
                 openLink(m_highlightedURL);
@@ -1223,7 +1223,7 @@ void IRCView::contentsMouseReleaseEvent(TQMouseEvent *ev)
 
 void IRCView::contentsMousePressEvent(TQMouseEvent* ev)
 {
-    if (ev->button() == Qt::LeftButton)
+    if (ev->button() == TQt::LeftButton)
     {
         m_urlToDrag = m_highlightedURL;
 
@@ -1432,9 +1432,9 @@ void IRCView::setupNickPopupMenu()
 
     m_nickPopup->insertItem(i18n("Add to Watched Nicks"), Konversation::AddNotify);
 
-    connect(m_nickPopup, TQT_SIGNAL(activated(int)), this, TQT_SIGNAL(popupCommand(int)));
-    connect(m_modes, TQT_SIGNAL(activated(int)), this, TQT_SIGNAL(popupCommand(int)));
-    connect(m_kickban, TQT_SIGNAL(activated(int)), this, TQT_SIGNAL(popupCommand(int)));
+    connect(m_nickPopup, TQ_SIGNAL(activated(int)), this, TQ_SIGNAL(popupCommand(int)));
+    connect(m_modes, TQ_SIGNAL(activated(int)), this, TQ_SIGNAL(popupCommand(int)));
+    connect(m_kickban, TQ_SIGNAL(activated(int)), this, TQ_SIGNAL(popupCommand(int)));
 }
 
 void IRCView::updateNickMenuEntries(TQPopupMenu* popup, const TQString& nickname)
@@ -1484,7 +1484,7 @@ void IRCView::setupQueryPopupMenu()
 
     m_nickPopup->insertItem(i18n("Add to Watched Nicks"), Konversation::AddNotify);
 
-    connect(m_nickPopup, TQT_SIGNAL(activated(int)), this, TQT_SIGNAL(popupCommand(int)));
+    connect(m_nickPopup, TQ_SIGNAL(activated(int)), this, TQ_SIGNAL(popupCommand(int)));
 }
 
 void IRCView::setupChannelPopupMenu()
@@ -1495,7 +1495,7 @@ void IRCView::setupChannelPopupMenu()
     m_channelPopup->insertItem(i18n("Get &user list"),Konversation::Names);
     m_channelPopup->insertItem(i18n("Get &topic"),Konversation::Topic);
 
-    connect(m_channelPopup, TQT_SIGNAL(activated(int)), this, TQT_SIGNAL(popupCommand(int)));
+    connect(m_channelPopup, TQ_SIGNAL(activated(int)), this, TQ_SIGNAL(popupCommand(int)));
 }
 
 void IRCView::setNickAndChannelContextMenusEnabled(bool enable)
@@ -1759,7 +1759,7 @@ void IRCView::resizeEvent(TQResizeEvent* e)
 
     if(doScroll)
     {
-        TQTimer::singleShot(0, this, TQT_SLOT(updateScrollBarPos()));
+        TQTimer::singleShot(0, this, TQ_SLOT(updateScrollBarPos()));
     }
 }
 
