@@ -78,7 +78,7 @@ ViewContainer::ViewContainer(KonversationMainWindow* window):
     m_dccPanel = new DccTransferPanel(m_tabWidget);
     m_dccPanel->hide();
     m_dccPanelOpen = false;
-    connect(m_dccPanel, TQT_SIGNAL(updateTabNotification(ChatWindow*,const Konversation::TabNotifyType&)), this, TQT_SLOT(setViewNotification(ChatWindow*,const Konversation::TabNotifyType&)));
+    connect(m_dccPanel, TQ_SIGNAL(updateTabNotification(ChatWindow*,const Konversation::TabNotifyType&)), this, TQ_SLOT(setViewNotification(ChatWindow*,const Konversation::TabNotifyType&)));
 }
 
 ViewContainer::~ViewContainer()
@@ -159,12 +159,12 @@ void ViewContainer::setupTabWidget()
     closeBtn->resize(22, 22);
     closeBtn->setSizePolicy(TQSizePolicy::Fixed, TQSizePolicy::Fixed);
     m_tabWidget->setCornerWidget(closeBtn);
-    connect(closeBtn, TQT_SIGNAL(clicked()), this, TQT_SLOT(closeCurrentView()));
+    connect(closeBtn, TQ_SIGNAL(clicked()), this, TQ_SLOT(closeCurrentView()));
 
-    connect(m_tabWidget, TQT_SIGNAL(currentChanged(TQWidget*)), this, TQT_SLOT (switchView(TQWidget*)));
-    connect(m_tabWidget, TQT_SIGNAL(closeRequest(TQWidget*)), this, TQT_SLOT(closeView(TQWidget*)));
-    connect(m_tabWidget, TQT_SIGNAL(contextMenu(TQWidget*, const TQPoint&)), this, TQT_SLOT(showViewContextMenu(TQWidget*, const TQPoint&)));
-    connect(m_tabWidget, TQT_SIGNAL(mouseMiddleClick(TQWidget*)), this, TQT_SLOT(closeViewMiddleClick(TQWidget*)));
+    connect(m_tabWidget, TQ_SIGNAL(currentChanged(TQWidget*)), this, TQ_SLOT (switchView(TQWidget*)));
+    connect(m_tabWidget, TQ_SIGNAL(closeRequest(TQWidget*)), this, TQ_SLOT(closeView(TQWidget*)));
+    connect(m_tabWidget, TQ_SIGNAL(contextMenu(TQWidget*, const TQPoint&)), this, TQ_SLOT(showViewContextMenu(TQWidget*, const TQPoint&)));
+    connect(m_tabWidget, TQ_SIGNAL(mouseMiddleClick(TQWidget*)), this, TQ_SLOT(closeViewMiddleClick(TQWidget*)));
 
     updateTabWidgetAppearance();
 }
@@ -175,16 +175,16 @@ void ViewContainer::setupViewTree()
     m_viewTreeSplitter->setResizeMode(m_viewTree, TQSplitter::KeepSize);
     m_viewTree->hide();
 
-    connect(KonversationApplication::instance(), TQT_SIGNAL(appearanceChanged()), m_viewTree, TQT_SLOT(updateAppearance()));
-    connect(this, TQT_SIGNAL(viewChanged(ChatWindow*)), m_viewTree, TQT_SLOT(selectView(ChatWindow*)));
-    connect(this, TQT_SIGNAL(removeView(ChatWindow*)), m_viewTree, TQT_SLOT(removeView(ChatWindow*)));
-    connect(this, TQT_SIGNAL(contextMenuClosed()), m_viewTree, TQT_SLOT(unHighlight()));
-    connect(m_viewTree, TQT_SIGNAL(setViewTreeShown(bool)), this, TQT_SLOT(setViewTreeShown(bool)));
-    connect(m_viewTree, TQT_SIGNAL(showView(ChatWindow*)), this, TQT_SLOT(showView(ChatWindow*)));
-    connect(m_viewTree, TQT_SIGNAL(closeView(ChatWindow*)), this, TQT_SLOT(closeView(ChatWindow*)));
-    connect(m_viewTree, TQT_SIGNAL(showViewContextMenu(TQWidget*, const TQPoint&)), this, TQT_SLOT(showViewContextMenu(TQWidget*, const TQPoint&)));
-    connect(m_viewTree, TQT_SIGNAL(sizeChanged()), this, TQT_SLOT(saveSplitterSizes()));
-    connect(m_viewTree, TQT_SIGNAL(syncTabBarToTree()), this, TQT_SLOT(syncTabBarToTree()));
+    connect(KonversationApplication::instance(), TQ_SIGNAL(appearanceChanged()), m_viewTree, TQ_SLOT(updateAppearance()));
+    connect(this, TQ_SIGNAL(viewChanged(ChatWindow*)), m_viewTree, TQ_SLOT(selectView(ChatWindow*)));
+    connect(this, TQ_SIGNAL(removeView(ChatWindow*)), m_viewTree, TQ_SLOT(removeView(ChatWindow*)));
+    connect(this, TQ_SIGNAL(contextMenuClosed()), m_viewTree, TQ_SLOT(unHighlight()));
+    connect(m_viewTree, TQ_SIGNAL(setViewTreeShown(bool)), this, TQ_SLOT(setViewTreeShown(bool)));
+    connect(m_viewTree, TQ_SIGNAL(showView(ChatWindow*)), this, TQ_SLOT(showView(ChatWindow*)));
+    connect(m_viewTree, TQ_SIGNAL(closeView(ChatWindow*)), this, TQ_SLOT(closeView(ChatWindow*)));
+    connect(m_viewTree, TQ_SIGNAL(showViewContextMenu(TQWidget*, const TQPoint&)), this, TQ_SLOT(showViewContextMenu(TQWidget*, const TQPoint&)));
+    connect(m_viewTree, TQ_SIGNAL(sizeChanged()), this, TQ_SLOT(saveSplitterSizes()));
+    connect(m_viewTree, TQ_SIGNAL(syncTabBarToTree()), this, TQ_SLOT(syncTabBarToTree()));
 
     TDEAction* action;
 
@@ -276,16 +276,16 @@ void ViewContainer::setViewTreeShown(bool show)
 
 void ViewContainer::removeViewTree()
 {
-    disconnect(KonversationApplication::instance(), TQT_SIGNAL(appearanceChanged()), m_viewTree, TQT_SLOT(updateAppearance()));
-    disconnect(this, TQT_SIGNAL(viewChanged(ChatWindow*)), m_viewTree, TQT_SLOT(selectView(ChatWindow*)));
-    disconnect(this, TQT_SIGNAL(removeView(ChatWindow*)), m_viewTree, TQT_SLOT(removeView(ChatWindow*)));
-    disconnect(this, TQT_SIGNAL(contextMenuClosed()), m_viewTree, TQT_SLOT(unHighlight()));
-    disconnect(m_viewTree, TQT_SIGNAL(setViewTreeShown(bool)), this, TQT_SLOT(setViewTreeShown(bool)));
-    disconnect(m_viewTree, TQT_SIGNAL(showView(ChatWindow*)), this, TQT_SLOT(showView(ChatWindow*)));
-    disconnect(m_viewTree, TQT_SIGNAL(closeView(ChatWindow*)), this, TQT_SLOT(closeView(ChatWindow*)));
-    disconnect(m_viewTree, TQT_SIGNAL(showViewContextMenu(TQWidget*, const TQPoint&)), this, TQT_SLOT(showViewContextMenu(TQWidget*, const TQPoint&)));
-    disconnect(m_viewTree, TQT_SIGNAL(sizeChanged()), this, TQT_SLOT(saveSplitterSizes()));
-    disconnect(m_viewTree, TQT_SIGNAL(syncTabBarToTree()), this, TQT_SLOT(syncTabBarToTree()));
+    disconnect(KonversationApplication::instance(), TQ_SIGNAL(appearanceChanged()), m_viewTree, TQ_SLOT(updateAppearance()));
+    disconnect(this, TQ_SIGNAL(viewChanged(ChatWindow*)), m_viewTree, TQ_SLOT(selectView(ChatWindow*)));
+    disconnect(this, TQ_SIGNAL(removeView(ChatWindow*)), m_viewTree, TQ_SLOT(removeView(ChatWindow*)));
+    disconnect(this, TQ_SIGNAL(contextMenuClosed()), m_viewTree, TQ_SLOT(unHighlight()));
+    disconnect(m_viewTree, TQ_SIGNAL(setViewTreeShown(bool)), this, TQ_SLOT(setViewTreeShown(bool)));
+    disconnect(m_viewTree, TQ_SIGNAL(showView(ChatWindow*)), this, TQ_SLOT(showView(ChatWindow*)));
+    disconnect(m_viewTree, TQ_SIGNAL(closeView(ChatWindow*)), this, TQ_SLOT(closeView(ChatWindow*)));
+    disconnect(m_viewTree, TQ_SIGNAL(showViewContextMenu(TQWidget*, const TQPoint&)), this, TQ_SLOT(showViewContextMenu(TQWidget*, const TQPoint&)));
+    disconnect(m_viewTree, TQ_SIGNAL(sizeChanged()), this, TQ_SLOT(saveSplitterSizes()));
+    disconnect(m_viewTree, TQ_SIGNAL(syncTabBarToTree()), this, TQ_SLOT(syncTabBarToTree()));
 
     TDEAction* action;
 
@@ -678,14 +678,14 @@ void ViewContainer::updateFrontView()
     // Make sure that only views with info output get to be the m_frontView
     if (m_frontView)
     {
-        disconnect(m_frontView, TQT_SIGNAL(updateInfo(const TQString &)), this, TQT_SIGNAL(setStatusBarInfoLabel(const TQString &)));
+        disconnect(m_frontView, TQ_SIGNAL(updateInfo(const TQString &)), this, TQ_SIGNAL(setStatusBarInfoLabel(const TQString &)));
     }
 
     if (view->canBeFrontView())
     {
         m_frontView = view;
 
-        connect(view, TQT_SIGNAL(updateInfo(const TQString &)), this, TQT_SIGNAL(setStatusBarInfoLabel(const TQString &)));
+        connect(view, TQ_SIGNAL(updateInfo(const TQString &)), this, TQ_SIGNAL(setStatusBarInfoLabel(const TQString &)));
         view->emitUpdateInfo();
     }
     else
@@ -1173,11 +1173,11 @@ void ViewContainer::addView(ChatWindow* view, const TQString& label, bool weinit
     ChatWindow::WindowType wtype;
     TQIconSet iconSet;
 
-    connect(KonversationApplication::instance(), TQT_SIGNAL(appearanceChanged()), view, TQT_SLOT(updateAppearance()));
-    connect(view, TQT_SIGNAL(setStatusBarTempText(const TQString&)), this, TQT_SIGNAL(setStatusBarTempText(const TQString&)));
-    connect(view, TQT_SIGNAL(clearStatusBarTempText()), this, TQT_SIGNAL(clearStatusBarTempText()));
-    connect(view, TQT_SIGNAL(closing(ChatWindow*)), this, TQT_SIGNAL(removeView(ChatWindow*)));
-    connect(view, TQT_SIGNAL(closing(ChatWindow*)), this, TQT_SLOT(cleanupAfterClose(ChatWindow*)));
+    connect(KonversationApplication::instance(), TQ_SIGNAL(appearanceChanged()), view, TQ_SLOT(updateAppearance()));
+    connect(view, TQ_SIGNAL(setStatusBarTempText(const TQString&)), this, TQ_SIGNAL(setStatusBarTempText(const TQString&)));
+    connect(view, TQ_SIGNAL(clearStatusBarTempText()), this, TQ_SIGNAL(clearStatusBarTempText()));
+    connect(view, TQ_SIGNAL(closing(ChatWindow*)), this, TQ_SIGNAL(removeView(ChatWindow*)));
+    connect(view, TQ_SIGNAL(closing(ChatWindow*)), this, TQ_SLOT(cleanupAfterClose(ChatWindow*)));
 
     // Please be careful about changing any of the grouping behavior in here,
     // because it needs to match up with the sorting behavior of the tree list,
@@ -1380,7 +1380,7 @@ void ViewContainer::switchView(TQWidget* newView)
     {
         m_frontView->resetTabNotification();
 
-        disconnect(m_frontView, TQT_SIGNAL(updateInfo(const TQString &)), this, TQT_SIGNAL(setStatusBarInfoLabel(const TQString &)));
+        disconnect(m_frontView, TQ_SIGNAL(updateInfo(const TQString &)), this, TQ_SIGNAL(setStatusBarInfoLabel(const TQString &)));
 
         if (Preferences::automaticRememberLine() && m_frontView->isInsertSupported())
             m_frontView->getTextView()->insertRememberLine();
@@ -1422,7 +1422,7 @@ void ViewContainer::switchView(TQWidget* newView)
 
 void ViewContainer::showView(ChatWindow* view)
 {
-    // Don't bring Tab to front if TabWidget is hidden. Otherwise QT gets confused
+    // Don't bring Tab to front if TabWidget is hidden. Otherwise TQt gets confused
     // and shows the Tab as active but will display the wrong pane
     if (m_tabWidget && m_tabWidget->isVisible())
         m_tabWidget->showPage(view);
@@ -1860,7 +1860,7 @@ void ViewContainer::insertCharacter()
     if (!m_insertCharDialog)
     {
         m_insertCharDialog = new Konversation::InsertCharDialog(font.family(), m_window);
-        connect(m_insertCharDialog, TQT_SIGNAL(insertChar(const TQChar&)), this, TQT_SLOT(insertChar(const TQChar&)));
+        connect(m_insertCharDialog, TQ_SIGNAL(insertChar(const TQChar&)), this, TQ_SLOT(insertChar(const TQChar&)));
     }
 
     m_insertCharDialog->setFont(font);
@@ -1979,8 +1979,8 @@ void ViewContainer::addKonsolePanel()
     KonsolePanel* panel=new KonsolePanel(m_tabWidget);
     panel->setName(i18n("Konsole"));
     addView(panel, i18n("Konsole"));
-    connect(panel, TQT_SIGNAL(updateTabNotification(ChatWindow*,const Konversation::TabNotifyType&)), this, TQT_SLOT(setViewNotification(ChatWindow*,const Konversation::TabNotifyType&)));
-    connect(panel, TQT_SIGNAL(closeView(ChatWindow*)), this, TQT_SLOT(closeView(ChatWindow*)));
+    connect(panel, TQ_SIGNAL(updateTabNotification(ChatWindow*,const Konversation::TabNotifyType&)), this, TQ_SLOT(setViewNotification(ChatWindow*,const Konversation::TabNotifyType&)));
+    connect(panel, TQ_SIGNAL(closeView(ChatWindow*)), this, TQ_SLOT(closeView(ChatWindow*)));
 }
 
 void ViewContainer::addUrlCatcher()
@@ -1991,12 +1991,12 @@ void ViewContainer::addUrlCatcher()
         m_urlCatcherPanel=new UrlCatcher(m_tabWidget);
         addView(m_urlCatcherPanel, i18n("URL Catcher"));
         KonversationApplication *konvApp=static_cast<KonversationApplication *>(TDEApplication::kApplication());
-        connect(konvApp,TQT_SIGNAL(catchUrl(const TQString&,const TQString&)),
-            m_urlCatcherPanel, TQT_SLOT(addUrl(const TQString&,const TQString&)) );
-        connect(m_urlCatcherPanel, TQT_SIGNAL(deleteUrl(const TQString&,const TQString&)),
-            konvApp, TQT_SLOT(deleteUrl(const TQString&,const TQString&)) );
-        connect(m_urlCatcherPanel, TQT_SIGNAL(clearUrlList()),
-            konvApp, TQT_SLOT(clearUrlList()));
+        connect(konvApp,TQ_SIGNAL(catchUrl(const TQString&,const TQString&)),
+            m_urlCatcherPanel, TQ_SLOT(addUrl(const TQString&,const TQString&)) );
+        connect(m_urlCatcherPanel, TQ_SIGNAL(deleteUrl(const TQString&,const TQString&)),
+            konvApp, TQ_SLOT(deleteUrl(const TQString&,const TQString&)) );
+        connect(m_urlCatcherPanel, TQ_SIGNAL(clearUrlList()),
+            konvApp, TQ_SLOT(clearUrlList()));
 
         TQStringList urlList=konvApp->getUrlList();
         for(unsigned int index=0;index<urlList.count();index++)
@@ -2081,7 +2081,7 @@ void ViewContainer::addDccChat(const TQString& myNick,const TQString& nick,const
             ? new DccChat(m_tabWidget, listen, m_frontServer, myNick, nick )
             : new DccChat(m_tabWidget, listen, m_frontServer, myNick, nick, arguments[1], arguments[2].toInt() );
 
-        connect(dccChatPanel, TQT_SIGNAL(updateTabNotification(ChatWindow*,const Konversation::TabNotifyType&)), this, TQT_SLOT(setViewNotification(ChatWindow*,const Konversation::TabNotifyType&)));
+        connect(dccChatPanel, TQ_SIGNAL(updateTabNotification(ChatWindow*,const Konversation::TabNotifyType&)), this, TQ_SLOT(setViewNotification(ChatWindow*,const Konversation::TabNotifyType&)));
 
         // This needs to be here as addView will change m_frontServer if focus new tabs is enabled.
         addView(dccChatPanel, dccChatPanel->getName());
@@ -2101,16 +2101,16 @@ StatusPanel* ViewContainer::addStatusView(Server* server)
     TQString label = server->getDisplayName();
     statusView->setName(label);
 
-    TQObject::connect(server, TQT_SIGNAL(sslInitFailure()), this, TQT_SIGNAL(removeStatusBarSSLLabel()));
-    TQObject::connect(server, TQT_SIGNAL(sslConnected(Server*)), this, TQT_SIGNAL(updateStatusBarSSLLabel(Server*)));
+    TQObject::connect(server, TQ_SIGNAL(sslInitFailure()), this, TQ_SIGNAL(removeStatusBarSSLLabel()));
+    TQObject::connect(server, TQ_SIGNAL(sslConnected(Server*)), this, TQ_SIGNAL(updateStatusBarSSLLabel(Server*)));
 
     // ... then put it into the tab widget, otherwise we'd have a race with server member
     addView(statusView, label);
 
-    connect(statusView, TQT_SIGNAL(updateTabNotification(ChatWindow*,const Konversation::TabNotifyType&)),
-        this, TQT_SLOT(setViewNotification(ChatWindow*,const Konversation::TabNotifyType&)));
-    connect(statusView, TQT_SIGNAL(sendFile()), server, TQT_SLOT(requestDccSend()));
-    connect(server, TQT_SIGNAL(awayState(bool)), statusView, TQT_SLOT(indicateAway(bool)) );
+    connect(statusView, TQ_SIGNAL(updateTabNotification(ChatWindow*,const Konversation::TabNotifyType&)),
+        this, TQ_SLOT(setViewNotification(ChatWindow*,const Konversation::TabNotifyType&)));
+    connect(statusView, TQ_SIGNAL(sendFile()), server, TQ_SLOT(requestDccSend()));
+    connect(server, TQ_SIGNAL(awayState(bool)), statusView, TQ_SLOT(indicateAway(bool)) );
 
     // make sure that m_frontServer gets set on adding the first status panel, too,
     // since there won't be a switchView happening
@@ -2129,8 +2129,8 @@ RawLog* ViewContainer::addRawLog(Server* server)
 
     addView(rawLog, i18n("Raw Log"));
 
-    connect(rawLog, TQT_SIGNAL(updateTabNotification(ChatWindow*,const Konversation::TabNotifyType&)),
-        this, TQT_SLOT(setViewNotification(ChatWindow*,const Konversation::TabNotifyType&)));
+    connect(rawLog, TQ_SIGNAL(updateTabNotification(ChatWindow*,const Konversation::TabNotifyType&)),
+        this, TQ_SLOT(setViewNotification(ChatWindow*,const Konversation::TabNotifyType&)));
 
     return rawLog;
 }
@@ -2227,10 +2227,10 @@ Channel* ViewContainer::addChannel(Server* server, const TQString& name)
     channel->setName(name); //still have to do this for now
     addView(channel, name);
 
-    connect(this, TQT_SIGNAL(updateChannelAppearance()), channel, TQT_SLOT(updateAppearance()));
-    connect(channel, TQT_SIGNAL(updateTabNotification(ChatWindow*,const Konversation::TabNotifyType&)), this, TQT_SLOT(setViewNotification(ChatWindow*,const Konversation::TabNotifyType&)));
-    connect(server, TQT_SIGNAL(awayState(bool)), channel, TQT_SLOT(indicateAway(bool)) );
-    connect(channel, TQT_SIGNAL(joined(Channel*)), this, TQT_SLOT(channelJoined(Channel*)));
+    connect(this, TQ_SIGNAL(updateChannelAppearance()), channel, TQ_SLOT(updateAppearance()));
+    connect(channel, TQ_SIGNAL(updateTabNotification(ChatWindow*,const Konversation::TabNotifyType&)), this, TQ_SLOT(setViewNotification(ChatWindow*,const Konversation::TabNotifyType&)));
+    connect(server, TQ_SIGNAL(awayState(bool)), channel, TQ_SLOT(indicateAway(bool)) );
+    connect(channel, TQ_SIGNAL(joined(Channel*)), this, TQ_SLOT(channelJoined(Channel*)));
 
     return channel;
 }
@@ -2284,9 +2284,9 @@ Query* ViewContainer::addQuery(Server* server, const NickInfoPtr& nickInfo, bool
 
     ++m_queryViewCount;
 
-    connect(query, TQT_SIGNAL(updateTabNotification(ChatWindow*,const Konversation::TabNotifyType&)), this, TQT_SLOT(setViewNotification(ChatWindow*,const Konversation::TabNotifyType&)));
-    connect(query, TQT_SIGNAL(updateQueryChrome(ChatWindow*, const TQString &)), this, TQT_SLOT(updateQueryChrome(ChatWindow*, const TQString &)));
-    connect(server, TQT_SIGNAL(awayState(bool)), query, TQT_SLOT(indicateAway(bool)));
+    connect(query, TQ_SIGNAL(updateTabNotification(ChatWindow*,const Konversation::TabNotifyType&)), this, TQ_SLOT(setViewNotification(ChatWindow*,const Konversation::TabNotifyType&)));
+    connect(query, TQ_SIGNAL(updateQueryChrome(ChatWindow*, const TQString &)), this, TQ_SLOT(updateQueryChrome(ChatWindow*, const TQString &)));
+    connect(server, TQ_SIGNAL(awayState(bool)), query, TQ_SLOT(indicateAway(bool)));
 
     return query;
 }
@@ -2400,10 +2400,10 @@ void ViewContainer::openNicksOnlinePanel()
     {
         m_nicksOnlinePanel=new NicksOnline(m_window);
         addView(m_nicksOnlinePanel, i18n("Watched Nicks Online"));
-        connect(m_nicksOnlinePanel, TQT_SIGNAL(editClicked()), m_window, TQT_SLOT(openNotify()));
-        connect(m_nicksOnlinePanel, TQT_SIGNAL(doubleClicked(const TQString&,const TQString&)), m_window, TQT_SLOT(notifyAction(const TQString&,const TQString&)));
-        connect(m_nicksOnlinePanel, TQT_SIGNAL(showView(ChatWindow*)), this, TQT_SLOT(showView(ChatWindow*)));
-        connect(m_window, TQT_SIGNAL(nicksNowOnline(Server*)), m_nicksOnlinePanel, TQT_SLOT(updateServerOnlineList(Server*)));
+        connect(m_nicksOnlinePanel, TQ_SIGNAL(editClicked()), m_window, TQ_SLOT(openNotify()));
+        connect(m_nicksOnlinePanel, TQ_SIGNAL(doubleClicked(const TQString&,const TQString&)), m_window, TQ_SLOT(notifyAction(const TQString&,const TQString&)));
+        connect(m_nicksOnlinePanel, TQ_SIGNAL(showView(ChatWindow*)), this, TQ_SLOT(showView(ChatWindow*)));
+        connect(m_window, TQ_SIGNAL(nicksNowOnline(Server*)), m_nicksOnlinePanel, TQ_SLOT(updateServerOnlineList(Server*)));
         (dynamic_cast<TDEToggleAction*>(actionCollection()->action("open_nicksonline_window")))->setChecked(true);
     }
     else
