@@ -101,20 +101,20 @@ void CalendarPanel::init( const TQDate &dt )
   monthForward->setPixmap(BarIcon(TQString::fromLatin1("1rightarrow")));
   monthBackward->setPixmap(BarIcon(TQString::fromLatin1("1leftarrow")));
   setDate(dt); // set button texts
-  connect(table, TQT_SIGNAL(dateChanged(TQDate)), TQT_SLOT(dateChangedSlot(TQDate)));
-  connect(table, TQT_SIGNAL(tableClicked()), TQT_SLOT(tableClickedSlot()));
-  connect(monthForward, TQT_SIGNAL(clicked()), TQT_SLOT(monthForwardClicked()));
-  connect(monthBackward, TQT_SIGNAL(clicked()), TQT_SLOT(monthBackwardClicked()));
-  connect(yearForward, TQT_SIGNAL(clicked()), TQT_SLOT(yearForwardClicked()));
-  connect(yearBackward, TQT_SIGNAL(clicked()), TQT_SLOT(yearBackwardClicked()));
-  connect(d->selectWeek, TQT_SIGNAL(clicked()), TQT_SLOT(selectWeekClicked()));
-  connect(selectMonth, TQT_SIGNAL(clicked()), TQT_SLOT(selectMonthClicked()));
-  connect(selectYear, TQT_SIGNAL(clicked()), TQT_SLOT(selectYearClicked()));
-  connect(line, TQT_SIGNAL(returnPressed()), TQT_SLOT(lineEnterPressed()));
+  connect(table, TQ_SIGNAL(dateChanged(TQDate)), TQ_SLOT(dateChangedSlot(TQDate)));
+  connect(table, TQ_SIGNAL(tableClicked()), TQ_SLOT(tableClickedSlot()));
+  connect(monthForward, TQ_SIGNAL(clicked()), TQ_SLOT(monthForwardClicked()));
+  connect(monthBackward, TQ_SIGNAL(clicked()), TQ_SLOT(monthBackwardClicked()));
+  connect(yearForward, TQ_SIGNAL(clicked()), TQ_SLOT(yearForwardClicked()));
+  connect(yearBackward, TQ_SIGNAL(clicked()), TQ_SLOT(yearBackwardClicked()));
+  connect(d->selectWeek, TQ_SIGNAL(clicked()), TQ_SLOT(selectWeekClicked()));
+  connect(selectMonth, TQ_SIGNAL(clicked()), TQ_SLOT(selectMonthClicked()));
+  connect(selectYear, TQ_SIGNAL(clicked()), TQ_SLOT(selectYearClicked()));
+  connect(line, TQ_SIGNAL(returnPressed()), TQ_SLOT(lineEnterPressed()));
 
-  connect(table, TQT_SIGNAL(weekdaySelected(int)), TQT_SLOT(slotWeekdaySelected(int)));
-  connect(table, TQT_SIGNAL(weekSelected(int, int)), TQT_SLOT(slotWeekSelected(int, int)));
-  connect(table, TQT_SIGNAL(selectionCleared()), TQT_SLOT(slotSelectionCleared()));
+  connect(table, TQ_SIGNAL(weekdaySelected(int)), TQ_SLOT(slotWeekdaySelected(int)));
+  connect(table, TQ_SIGNAL(weekSelected(int, int)), TQ_SLOT(slotWeekSelected(int, int)));
+  connect(table, TQ_SIGNAL(selectionCleared()), TQ_SLOT(slotSelectionCleared()));
 
   table->setFocus();
 }
@@ -137,7 +137,7 @@ CalendarPanel::eventFilter(TQObject *o, TQEvent *e )
        {
           TQApplication::sendEvent( table, e );
           table->setFocus();
-          return TRUE; // eat event
+          return true; // eat event
        }
    }
    return TQFrame::eventFilter( o, e );
@@ -174,7 +174,7 @@ CalendarPanel::resizeEvent(TQResizeEvent*)
     // ----- calculate size of the month button:
     for(count=0; count<NoOfButtons; ++count) {
         if(buttons[count]==selectMonth) {
-            TQSize metricBound = style().tqsizeFromContents(TQStyle::CT_ToolButton, selectMonth, maxMonthRect);
+            TQSize metricBound = style().sizeFromContents(TQStyle::CT_ToolButton, selectMonth, maxMonthRect);
             sizes[count].setWidth(TQMAX(metricBound.width(), maxMonthRect.width()+2*TQApplication::style().pixelMetric(TQStyle::PM_ButtonMargin)));
         }
     }
@@ -287,7 +287,7 @@ CalendarPanel::selectWeekClicked()
   // -----
   picker->resize(picker->sizeHint());
   popup->setMainWidget(picker);
-  connect(picker, TQT_SIGNAL(closeMe(int)), popup, TQT_SLOT(close(int)));
+  connect(picker, TQ_SIGNAL(closeMe(int)), popup, TQ_SLOT(close(int)));
   picker->setFocus();
   if(popup->exec(d->selectWeek->mapToGlobal(TQPoint(0, d->selectWeek->height()))))
     {
@@ -325,7 +325,7 @@ CalendarPanel::selectMonthClicked()
   picker->resize(picker->sizeHint());
   popup->setMainWidget(picker);
   picker->setFocus();
-  connect(picker, TQT_SIGNAL(closeMe(int)), popup, TQT_SLOT(close(int)));
+  connect(picker, TQ_SIGNAL(closeMe(int)), popup, TQ_SLOT(close(int)));
   if(popup->exec(selectMonth->mapToGlobal(TQPoint(0, selectMonth->height()))))
     {
       TQDate date;
@@ -354,7 +354,7 @@ CalendarPanel::selectYearClicked()
   // -----
   picker->resize(picker->sizeHint());
   popup->setMainWidget(picker);
-  connect(picker, TQT_SIGNAL(closeMe(int)), popup, TQT_SLOT(close(int)));
+  connect(picker, TQ_SIGNAL(closeMe(int)), popup, TQ_SLOT(close(int)));
   picker->setFocus();
   if(popup->exec(selectYear->mapToGlobal(TQPoint(0, selectMonth->height()))))
     {
@@ -432,7 +432,7 @@ CalendarPanel::sizeHint() const
             sizes[count] = TQSize(0,0);
 
         if(buttons[count]==selectMonth) {
-	        TQSize metricBound = style().tqsizeFromContents(TQStyle::CT_ToolButton, selectMonth, maxMonthRect);
+	        TQSize metricBound = style().sizeFromContents(TQStyle::CT_ToolButton, selectMonth, maxMonthRect);
             cx+=TQMAX(metricBound.width(), maxMonthRect.width()+2*TQApplication::style().pixelMetric(TQStyle::PM_ButtonMargin));
     	} else {
 	        cx+=sizes[count].width();
@@ -489,8 +489,8 @@ CalendarPanel::setCloseButton( bool enable )
         d->closeButton = new TQToolButton( this );
         TQToolTip::add(d->closeButton, i18n("Close"));
         d->closeButton->setPixmap( SmallIcon("remove") );
-        connect( d->closeButton, TQT_SIGNAL( clicked() ),
-                 topLevelWidget(), TQT_SLOT( close() ) );
+        connect( d->closeButton, TQ_SIGNAL( clicked() ),
+                 topLevelWidget(), TQ_SLOT( close() ) );
     }
     else {
         delete d->closeButton;
