@@ -188,17 +188,17 @@ ReportView::ReportView(View *view, TQWidget *parent)
 
     initReportList();
     
-	connect(m_reportList, TQT_SIGNAL(clicked(TQListViewItem*)), TQT_SLOT(slotReportListClicked(TQListViewItem*)));
-	connect(m_reportList, TQT_SIGNAL(selectionChanged(TQListViewItem*)), TQT_SLOT(slotReportListSelectionChanged(TQListViewItem*)));
+	connect(m_reportList, TQ_SIGNAL(clicked(TQListViewItem*)), TQ_SLOT(slotReportListClicked(TQListViewItem*)));
+	connect(m_reportList, TQ_SIGNAL(selectionChanged(TQListViewItem*)), TQ_SLOT(slotReportListSelectionChanged(TQListViewItem*)));
 
 	//setCentralWidget(m_reportview);
 
 	// Create the user interface.
-	//KStdAction::print(this,TQT_SLOT(slotPrint()),actionCollection());
-	//KStdAction::quit(this,TQT_SLOT(slotFileQuit()),actionCollection());
+	//KStdAction::print(this,TQ_SLOT(slotPrint()),actionCollection());
+	//KStdAction::quit(this,TQ_SLOT(slotFileQuit()),actionCollection());
 
-//	KStdAction::showToolbar(this,TQT_SLOT(slotViewToolBar()),actionCollection());
-//	KStdAction::showStatusbar(this,TQT_SLOT(slotViewStatusBar()),actionCollection());
+//	KStdAction::showToolbar(this,TQ_SLOT(slotViewToolBar()),actionCollection());
+//	KStdAction::showStatusbar(this,TQ_SLOT(slotViewStatusBar()),actionCollection());
 
 // 	statusBar();
 
