@@ -267,19 +267,19 @@ void KWMailMergeTDEABCConfig::initSelectedLists()
 
 void KWMailMergeTDEABCConfig::initSlotSignalConnections()
 {
-    connect( this, TQT_SIGNAL( okClicked() ), TQT_SLOT( acceptSelection() ) );
-    connect( _ui->mAddButton, TQT_SIGNAL( clicked() ), TQT_SLOT( addSelectedContacts() ) );
-    connect( _ui->mAddressBook, TQT_SIGNAL( clicked() ), TQT_SLOT( launchAddressbook() ) );
+    connect( this, TQ_SIGNAL( okClicked() ), TQ_SLOT( acceptSelection() ) );
+    connect( _ui->mAddButton, TQ_SIGNAL( clicked() ), TQ_SLOT( addSelectedContacts() ) );
+    connect( _ui->mAddressBook, TQ_SIGNAL( clicked() ), TQ_SLOT( launchAddressbook() ) );
 
-    connect( _ui->mAvailableView, TQT_SIGNAL( doubleClicked( TQListViewItem *, const TQPoint &, int ) ),
-             TQT_SLOT( addSelectedContacts() ) );
+    connect( _ui->mAvailableView, TQ_SIGNAL( doubleClicked( TQListViewItem *, const TQPoint &, int ) ),
+             TQ_SLOT( addSelectedContacts() ) );
 
-    connect( _ui->mFilterEdit, TQT_SIGNAL( textChanged(const TQString &) ),
-             TQT_SLOT( filterChanged(const TQString &) ) );
-    connect( _ui->mRemoveButton, TQT_SIGNAL( clicked() ), TQT_SLOT( removeSelectedContacts() ) );
-    connect( _ui->mSaveList, TQT_SIGNAL( clicked() ), TQT_SLOT( saveDistributionList() ) );
-    connect( _ui->mSelectedView, TQT_SIGNAL( doubleClicked( TQListViewItem *, const TQPoint &, int ) ),
-             TQT_SLOT( removeSelectedContacts() ) );
+    connect( _ui->mFilterEdit, TQ_SIGNAL( textChanged(const TQString &) ),
+             TQ_SLOT( filterChanged(const TQString &) ) );
+    connect( _ui->mRemoveButton, TQ_SIGNAL( clicked() ), TQ_SLOT( removeSelectedContacts() ) );
+    connect( _ui->mSaveList, TQ_SIGNAL( clicked() ), TQ_SLOT( saveDistributionList() ) );
+    connect( _ui->mSelectedView, TQ_SIGNAL( doubleClicked( TQListViewItem *, const TQPoint &, int ) ),
+             TQ_SLOT( removeSelectedContacts() ) );
 }
 
 
