@@ -713,7 +713,7 @@ bool TDEQt4PaintDevice::cmd( int c, TQPainter *pt, TQPDevCmdParam *p )
 #endif
 	}
 
-	return TRUE;
+	return true;
 }
 
 
