@@ -34,27 +34,27 @@ StreamingConfiguration::StreamingConfiguration (TQWidget *parent, StreamingDevic
    m_dirty(true),
    m_StreamingDevice(streamer)
 {
-    connect(m_pbNewPlaybackURL,    TQT_SIGNAL(clicked()), this, TQT_SLOT(slotNewPlaybackChannel()));
-    connect(m_pbDeletePlaybackURL, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotDeletePlaybackChannel()));
-    connect(m_pbUpPlaybackURL,     TQT_SIGNAL(clicked()), this, TQT_SLOT(slotUpPlaybackChannel()));
-    connect(m_pbDownPlaybackURL,   TQT_SIGNAL(clicked()), this, TQT_SLOT(slotDownPlaybackChannel()));
-    connect(m_ListPlaybackURLs,    TQT_SIGNAL(selectionChanged()),           this, TQT_SLOT(slotPlaybackSelectionChanged()));
-    connect(m_ListPlaybackURLs,    TQT_SIGNAL(itemRenamed(TQListViewItem *)), this, TQT_SLOT(slotSetDirty()));
+    connect(m_pbNewPlaybackURL,    TQ_SIGNAL(clicked()), this, TQ_SLOT(slotNewPlaybackChannel()));
+    connect(m_pbDeletePlaybackURL, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotDeletePlaybackChannel()));
+    connect(m_pbUpPlaybackURL,     TQ_SIGNAL(clicked()), this, TQ_SLOT(slotUpPlaybackChannel()));
+    connect(m_pbDownPlaybackURL,   TQ_SIGNAL(clicked()), this, TQ_SLOT(slotDownPlaybackChannel()));
+    connect(m_ListPlaybackURLs,    TQ_SIGNAL(selectionChanged()),           this, TQ_SLOT(slotPlaybackSelectionChanged()));
+    connect(m_ListPlaybackURLs,    TQ_SIGNAL(itemRenamed(TQListViewItem *)), this, TQ_SLOT(slotSetDirty()));
 
-    connect(m_pbNewCaptureURL,     TQT_SIGNAL(clicked()), this, TQT_SLOT(slotNewCaptureChannel()));
-    connect(m_pbDeleteCaptureURL,  TQT_SIGNAL(clicked()), this, TQT_SLOT(slotDeleteCaptureChannel()));
-    connect(m_pbUpCaptureURL,      TQT_SIGNAL(clicked()), this, TQT_SLOT(slotUpCaptureChannel()));
-    connect(m_pbDownCaptureURL,    TQT_SIGNAL(clicked()), this, TQT_SLOT(slotDownCaptureChannel()));
-    connect(m_ListCaptureURLs,     TQT_SIGNAL(selectionChanged()),           this, TQT_SLOT(slotCaptureSelectionChanged()));
-    connect(m_ListCaptureURLs,     TQT_SIGNAL(itemRenamed(TQListViewItem *)), this, TQT_SLOT(slotSetDirty()));
+    connect(m_pbNewCaptureURL,     TQ_SIGNAL(clicked()), this, TQ_SLOT(slotNewCaptureChannel()));
+    connect(m_pbDeleteCaptureURL,  TQ_SIGNAL(clicked()), this, TQ_SLOT(slotDeleteCaptureChannel()));
+    connect(m_pbUpCaptureURL,      TQ_SIGNAL(clicked()), this, TQ_SLOT(slotUpCaptureChannel()));
+    connect(m_pbDownCaptureURL,    TQ_SIGNAL(clicked()), this, TQ_SLOT(slotDownCaptureChannel()));
+    connect(m_ListCaptureURLs,     TQ_SIGNAL(selectionChanged()),           this, TQ_SLOT(slotCaptureSelectionChanged()));
+    connect(m_ListCaptureURLs,     TQ_SIGNAL(itemRenamed(TQListViewItem *)), this, TQ_SLOT(slotSetDirty()));
 
-    connect(m_cbBits,       TQT_SIGNAL(activated(int)),    this, TQT_SLOT(slotUpdateSoundFormat()));
-    connect(m_cbChannels,   TQT_SIGNAL(activated(int)),    this, TQT_SLOT(slotUpdateSoundFormat()));
-    connect(m_cbEndianess,  TQT_SIGNAL(activated(int)),    this, TQT_SLOT(slotUpdateSoundFormat()));
-    connect(m_cbFormat,     TQT_SIGNAL(activated(int)),    this, TQT_SLOT(slotUpdateSoundFormat()));
-    connect(m_cbRate,       TQT_SIGNAL(activated(int)),    this, TQT_SLOT(slotUpdateSoundFormat()));
-    connect(m_cbSign,       TQT_SIGNAL(activated(int)),    this, TQT_SLOT(slotUpdateSoundFormat()));
-    connect(m_sbBufferSize, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(slotUpdateSoundFormat()));
+    connect(m_cbBits,       TQ_SIGNAL(activated(int)),    this, TQ_SLOT(slotUpdateSoundFormat()));
+    connect(m_cbChannels,   TQ_SIGNAL(activated(int)),    this, TQ_SLOT(slotUpdateSoundFormat()));
+    connect(m_cbEndianess,  TQ_SIGNAL(activated(int)),    this, TQ_SLOT(slotUpdateSoundFormat()));
+    connect(m_cbFormat,     TQ_SIGNAL(activated(int)),    this, TQ_SLOT(slotUpdateSoundFormat()));
+    connect(m_cbRate,       TQ_SIGNAL(activated(int)),    this, TQ_SLOT(slotUpdateSoundFormat()));
+    connect(m_cbSign,       TQ_SIGNAL(activated(int)),    this, TQ_SLOT(slotUpdateSoundFormat()));
+    connect(m_sbBufferSize, TQ_SIGNAL(valueChanged(int)), this, TQ_SLOT(slotUpdateSoundFormat()));
 
     m_ListPlaybackURLs->setAllColumnsShowFocus(true);
     m_ListPlaybackURLs->setSorting(-1);
