@@ -41,7 +41,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-bool Uic::isMainWindow = FALSE;
+bool Uic::isMainWindow = false;
 PyIndent Uic::indent;
 
 
@@ -109,13 +109,13 @@ TQString Uic::trcall( const TQString& sourceText, const TQString& comment )
    if ( sourceText.isEmpty() && comment.isEmpty() )
 	return "\"\"";
    TQString t = trmacro;
-    bool encode = FALSE;
+    bool encode = false;
     if ( t.isNull() ) {
 	t = "tr";
 	for ( int i = 0; i < (int) sourceText.length(); i++ ) {
 	    if ( sourceText[i].unicode() >= 0x80 ) {
 		t = "trUtf8";
-		encode = TRUE;
+		encode = true;
 		break;
 	    }
 	}
@@ -144,7 +144,7 @@ Uic::Uic( const TQString &fn, const char *outputFn, TQTextStream &outStream,
       outputFileName( outputFn ), trmacro( trm ), nofwd( omitForwardDecls )
 {
     fileName = fn;
-    writeFunctImpl = TRUE;
+    writeFunctImpl = true;
     defMargin = BOXLAYOUT_DEFAULT_MARGIN;
     defSpacing = BOXLAYOUT_DEFAULT_SPACING;
     externPixmaps = FALSE;
@@ -259,16 +259,16 @@ TQString Uic::getClassName( const TQDomElement& e )
 
 
 
-/*! Returns TRUE if database framework code is generated, else FALSE.
+/*! Returns true if database framework code is generated, else false.
 */
 
 bool Uic::isFrameworkCodeGenerated( const TQDomElement& e )
 {
     TQDomElement n = getObjectProperty( e, "frameworkCode" );
     if ( n.attribute("name") == "frameworkCode" &&
-	 !DomTool::elementToVariant( n.firstChild().toElement(), TQVariant( TRUE ) ).toBool() )
-	return FALSE;
-    return TRUE;
+	 !DomTool::elementToVariant( n.firstChild().toElement(), TQVariant( true ) ).toBool() )
+	return false;
+    return true;
 }
 
 /*! Extracts an object name from \a e. It's stored in the 'name'
@@ -376,7 +376,7 @@ void Uic::createActionImpl( const TQDomElement &n, const TQString &parent )
 	    out << indent << objName << "= TQt::ActionGroup(" << parent << ", \"" << objName << "\");" << endl;
 	else
 	    continue;
-	bool subActionsDone = FALSE;
+	bool subActionsDone = false;
 	for ( TQDomElement n2 = ae.firstChild().toElement(); !n2.isNull(); n2 = n2.nextSibling().toElement() ) {
 	    if ( n2.tagName() == "property" ) {
 		bool stdset = stdsetdef;
@@ -408,7 +408,7 @@ void Uic::createActionImpl( const TQDomElement &n, const TQString &parent )
 		}
 	    } else if ( !subActionsDone && ( n2.tagName() == "actiongroup" || n2.tagName() == "action" ) ) {
 		createActionImpl( n2, objName );
-		subActionsDone = TRUE;
+		subActionsDone = true;
 	    }
 	}
     }
@@ -669,7 +669,7 @@ TQString Uic::createListViewColumnImpl( const TQDomElement &e, const TQString &p
     TQString txt;
     TQString com;
     TQString pix;
-    bool clickable = FALSE, resizable = FALSE;
+    bool clickable = false, resizable = false;
     while ( !n.isNull() ) {
 	if ( n.tagName() == "property" ) {
 	    TQString attrib = n.attribute("name");
@@ -968,7 +968,7 @@ TQColorGroup Uic::loadColorGroup( const TQDomElement &e )
     return cg;
 }
 
-/*!  Returns TRUE if the widget properties specify that it belongs to
+/*!  Returns true if the widget properties specify that it belongs to
   the database \a connection and \a table.
 */
 
@@ -977,8 +977,8 @@ bool Uic::isWidgetInTable( const TQDomElement& e, const TQString& connection, co
     TQString conn = getDatabaseInfo( e, "connection" );
     TQString tab = getDatabaseInfo( e, "table" );
     if ( conn == connection && tab == table )
-	return TRUE;
-    return FALSE;
+	return true;
+    return false;
 }
 
 /*!
