@@ -66,7 +66,7 @@ Smb4KSambaOptions::Smb4KSambaOptions( TQWidget *parent, const char *name )
   TQGridLayout *general_layout = new TQGridLayout( general_tab );
   general_layout->setSpacing( 10 );
 
-  TQGroupBox *general_options =  new TQGroupBox( 2, Qt::Horizontal,
+  TQGroupBox *general_options =  new TQGroupBox( 2, TQt::Horizontal,
                                 i18n( "General Options" ), general_tab );
   general_options->setInsideSpacing( 5 );
 
@@ -85,7 +85,7 @@ Smb4KSambaOptions::Smb4KSambaOptions( TQWidget *parent, const char *name )
   (void) new TQLabel( i18n( "Remote SMB port:" ), general_options );
   (void) new KIntNumInput( general_options, "kcfg_RemotePort" );
 
-  TQGroupBox *authentication =   new TQGroupBox( 1, Qt::Horizontal,
+  TQGroupBox *authentication =   new TQGroupBox( 1, TQt::Horizontal,
                                 i18n( "Authentication" ), general_tab );
 
   (void) new TQCheckBox( i18n( "Try to authenticate with Kerberos" ), authentication, "kcfg_UseKerberos" );
@@ -106,7 +106,7 @@ Smb4KSambaOptions::Smb4KSambaOptions( TQWidget *parent, const char *name )
   TQGridLayout *mount_layout =   new TQGridLayout( mount_tab );
   mount_layout->setSpacing( 10 );
 
-  TQGroupBox *filesystem_box =   new TQGroupBox( 1, Qt::Horizontal,
+  TQGroupBox *filesystem_box =   new TQGroupBox( 1, TQt::Horizontal,
                                 i18n( "File System" ), mount_tab );
 
 #ifndef __FreeBSD__
@@ -120,7 +120,7 @@ Smb4KSambaOptions::Smb4KSambaOptions( TQWidget *parent, const char *name )
   TQLabel *note =                new TQLabel( i18n( "NOTE: You might need to enable support for either \"super\" or \"sudo\" in the Super User page." ), filesystem_box );
   note->setTextFormat( TQt::RichText );
 
-  TQGroupBox *user_group_box =   new TQGroupBox( 2, Qt::Horizontal,
+  TQGroupBox *user_group_box =   new TQGroupBox( 2, TQt::Horizontal,
                                 i18n( "User and Group" ), mount_tab );
   user_group_box->setInsideSpacing( 5 );
 
@@ -132,7 +132,7 @@ Smb4KSambaOptions::Smb4KSambaOptions( TQWidget *parent, const char *name )
   KLineEdit *group_id =         new KLineEdit( user_group_box, "kcfg_GroupID" );
   group_id->setAlignment( TQt::AlignRight );
 
-  TQGroupBox *charset_box =      new TQGroupBox( 2, Qt::Horizontal,
+  TQGroupBox *charset_box =      new TQGroupBox( 2, TQt::Horizontal,
                                 i18n( "Charset and Codepage" ), mount_tab );
   charset_box->setInsideSpacing( 5 );
 
@@ -198,7 +198,7 @@ Smb4KSambaOptions::Smb4KSambaOptions( TQWidget *parent, const char *name )
   codepage->insertItem( "cp1258", Smb4KSettings::EnumServerCodepage::cp1258 );
   codepage->insertItem( "unicode", Smb4KSettings::EnumServerCodepage::unicode );
 
-  TQGroupBox *perms_box =        new TQGroupBox( 2, Qt::Horizontal,
+  TQGroupBox *perms_box =        new TQGroupBox( 2, TQt::Horizontal,
                                 i18n( "Permissions" ), mount_tab );
   perms_box->setInsideSpacing( 5 );
 
@@ -216,7 +216,7 @@ Smb4KSambaOptions::Smb4KSambaOptions( TQWidget *parent, const char *name )
   read_mode->insertItem( i18n( "read-only" ), Smb4KSettings::EnumWriteAccess::ReadOnly );
 
 #ifndef __FreeBSD__
-  TQGroupBox *advanced_cifs =    new TQGroupBox( 1, Qt::Horizontal,
+  TQGroupBox *advanced_cifs =    new TQGroupBox( 1, TQt::Horizontal,
                                 i18n( "Advanced CIFS Options" ), mount_tab, "AdvancedCIFSOptions" );
   advanced_cifs->setInsideSpacing( 5 );
 
@@ -244,7 +244,7 @@ Smb4KSambaOptions::Smb4KSambaOptions( TQWidget *parent, const char *name )
   c_extra_layout->addWidget( new TQLabel( i18n( "Additional options:" ), c_extra_widget ), 0, 0, 0 );
   c_extra_layout->addWidget( new KLineEdit( c_extra_widget, "kcfg_CustomCIFSOptions" ), 0, 1, 0 );
 
-  TQGroupBox *advanced_smbfs =   new TQGroupBox( 1, Qt::Horizontal,
+  TQGroupBox *advanced_smbfs =   new TQGroupBox( 1, TQt::Horizontal,
                                 i18n( "Advanced SMBFS Options" ), mount_tab, "AdvancedSMBFSOptions" );
   advanced_smbfs->setInsideSpacing( 5 );
 
@@ -285,7 +285,7 @@ Smb4KSambaOptions::Smb4KSambaOptions( TQWidget *parent, const char *name )
   TQGridLayout *net_layout =     new TQGridLayout( net_tab );
   net_layout->setSpacing( 10 );
 
-  TQButtonGroup *protocol_hint = new TQButtonGroup( 1, Qt::Horizontal,
+  TQButtonGroup *protocol_hint = new TQButtonGroup( 1, TQt::Horizontal,
                                 i18n( "Protocol Hint" ), net_tab, "kcfg_ProtocolHint" );
 
   protocol_hint->insert( new TQRadioButton( i18n( "Automatic detection" ), protocol_hint ),
@@ -311,7 +311,7 @@ Smb4KSambaOptions::Smb4KSambaOptions( TQWidget *parent, const char *name )
   TQGridLayout *smbclient_layout = new TQGridLayout( smbclient_tab );
   smbclient_layout->setSpacing( 10 );
 
-  TQGroupBox *smbclient_misc =   new TQGroupBox( 2, Qt::Horizontal, i18n( "Miscellaneous" ),
+  TQGroupBox *smbclient_misc =   new TQGroupBox( 2, TQt::Horizontal, i18n( "Miscellaneous" ),
                                 smbclient_tab, "SmbclientMiscellaneous" );
   smbclient_misc->setInsideSpacing( 5 );
 
@@ -343,7 +343,7 @@ Smb4KSambaOptions::Smb4KSambaOptions( TQWidget *parent, const char *name )
   TQGridLayout *nmblookup_layout = new TQGridLayout( nmblookup_tab );
   nmblookup_layout->setSpacing( 10 );
 
-  TQGroupBox *nmblookup_misc =   new TQGroupBox( 1, Qt::Horizontal,
+  TQGroupBox *nmblookup_misc =   new TQGroupBox( 1, TQt::Horizontal,
                                 i18n( "Miscellaneous" ), nmblookup_tab );
   nmblookup_misc->setInsideSpacing( 5 );
 
@@ -496,41 +496,41 @@ Smb4KSambaOptions::Smb4KSambaOptions( TQWidget *parent, const char *name )
   // Connections
   //
 #ifndef __FreeBSD__
-  connect( filesystem,      TQT_SIGNAL( activated( int ) ),
-           this,            TQT_SLOT( slotSambaFileSystem( int ) ) );
+  connect( filesystem,      TQ_SIGNAL( activated( int ) ),
+           this,            TQ_SLOT( slotSambaFileSystem( int ) ) );
 #endif
 
-  connect( remove_custom,   TQT_SIGNAL( clicked() ),
-           this,            TQT_SLOT( slotRemoveCustomOption() ) );
+  connect( remove_custom,   TQ_SIGNAL( clicked() ),
+           this,            TQ_SLOT( slotRemoveCustomOption() ) );
 
-  connect( rm_all_custom,   TQT_SIGNAL( clicked() ),
-           this,            TQT_SLOT( slotRemoveAllCustomOptions() ) );
+  connect( rm_all_custom,   TQ_SIGNAL( clicked() ),
+           this,            TQ_SLOT( slotRemoveAllCustomOptions() ) );
 
-  connect( custom_options,  TQT_SIGNAL( clicked( TQListViewItem * ) ),
-           this,            TQT_SLOT( slotCustomItemClicked( TQListViewItem * ) ) );
+  connect( custom_options,  TQ_SIGNAL( clicked( TQListViewItem * ) ),
+           this,            TQ_SLOT( slotCustomItemClicked( TQListViewItem * ) ) );
 
-  connect( custom_protocol, TQT_SIGNAL( activated( int ) ),
-           this,            TQT_SLOT( slotCustomProtocolChanged( int ) ) );
+  connect( custom_protocol, TQ_SIGNAL( activated( int ) ),
+           this,            TQ_SLOT( slotCustomProtocolChanged( int ) ) );
 
 #ifndef __FreeBSD__
-  connect( custom_fs,       TQT_SIGNAL( activated( int ) ),
-           this,            TQT_SLOT( slotCustomFileSystemChanged( int ) ) );
+  connect( custom_fs,       TQ_SIGNAL( activated( int ) ),
+           this,            TQ_SLOT( slotCustomFileSystemChanged( int ) ) );
 
-  connect( custom_rw,       TQT_SIGNAL( activated( int ) ),
-           this,            TQT_SLOT( slotCustomWriteAccessChanged( int ) ) );
+  connect( custom_rw,       TQ_SIGNAL( activated( int ) ),
+           this,            TQ_SLOT( slotCustomWriteAccessChanged( int ) ) );
 #endif
 
-  connect( custom_krb,      TQT_SIGNAL( activated( int ) ),
-           this,            TQT_SLOT( slotCustomKerberosChanged( int ) ) );
+  connect( custom_krb,      TQ_SIGNAL( activated( int ) ),
+           this,            TQ_SLOT( slotCustomKerberosChanged( int ) ) );
 
-  connect( custom_uid,      TQT_SIGNAL( textChanged( const TQString & ) ),
-           this,            TQT_SLOT( slotCustomUIDChanged( const TQString & ) ) );
+  connect( custom_uid,      TQ_SIGNAL( textChanged( const TQString & ) ),
+           this,            TQ_SLOT( slotCustomUIDChanged( const TQString & ) ) );
 
-  connect( custom_gid,      TQT_SIGNAL( textChanged( const TQString & ) ),
-           this,            TQT_SLOT( slotCustomGIDChanged( const TQString & ) ) );
+  connect( custom_gid,      TQ_SIGNAL( textChanged( const TQString & ) ),
+           this,            TQ_SLOT( slotCustomGIDChanged( const TQString & ) ) );
 
-  connect( custom_port,     TQT_SIGNAL( valueChanged( int ) ),
-           this,            TQT_SLOT( slotCustomPortChanged( int ) ) );
+  connect( custom_port,     TQ_SIGNAL( valueChanged( int ) ),
+           this,            TQ_SLOT( slotCustomPortChanged( int ) ) );
 
   //
   // Do last things before we are ready to go
@@ -554,7 +554,7 @@ void Smb4KSambaOptions::resetCustomTab()
 
 
 /////////////////////////////////////////////////////////////////////////////
-//  TQT_SLOT IMPLEMENTATIONS
+//  SLOT IMPLEMENTATIONS
 /////////////////////////////////////////////////////////////////////////////
 
 #ifndef __FreeBSD__
@@ -564,28 +564,28 @@ void Smb4KSambaOptions::slotSambaFileSystem( int item_index )
   {
     case Smb4KSettings::EnumFilesystem::CIFS:
     {
-      TQGroupBox *adv_cifs = static_cast<TQGroupBox *>( TQT_TQWIDGET(child( "AdvancedCIFSOptions", "TQGroupBox", true )) );
+      TQGroupBox *adv_cifs = static_cast<TQGroupBox *>( child( "AdvancedCIFSOptions", "TQGroupBox", true ) );
 
       if ( adv_cifs )
       {
         adv_cifs->setEnabled( true );
       }
 
-      TQGroupBox *adv_smbfs = static_cast<TQGroupBox *>( TQT_TQWIDGET(child( "AdvancedSMBFSOptions", "TQGroupBox", true )) );
+      TQGroupBox *adv_smbfs = static_cast<TQGroupBox *>( child( "AdvancedSMBFSOptions", "TQGroupBox", true ) );
 
       if ( adv_smbfs )
       {
         adv_smbfs->setEnabled( false );
       }
 
-      TQLabel *codepage = static_cast<TQLabel *>( TQT_TQWIDGET(child( "CodepageLabel", "TQLabel", true )) );
+      TQLabel *codepage = static_cast<TQLabel *>( child( "CodepageLabel", "TQLabel", true ) );
 
       if ( codepage )
       {
         codepage->setEnabled( false );
       }
 
-      KComboBox *srv_codepage = static_cast<KComboBox *>( TQT_TQWIDGET(child( "kcfg_ServerCodepage", "KComboBox", true )) );
+      KComboBox *srv_codepage = static_cast<KComboBox *>( child( "kcfg_ServerCodepage", "KComboBox", true ) );
 
       if ( srv_codepage )
       {
@@ -596,28 +596,28 @@ void Smb4KSambaOptions::slotSambaFileSystem( int item_index )
     }
     case Smb4KSettings::EnumFilesystem::SMBFS:
     {
-      TQGroupBox *adv_cifs = static_cast<TQGroupBox *>( TQT_TQWIDGET(child( "AdvancedCIFSOptions", "TQGroupBox", true )) );
+      TQGroupBox *adv_cifs = static_cast<TQGroupBox *>( child( "AdvancedCIFSOptions", "TQGroupBox", true ) );
 
       if ( adv_cifs )
       {
         adv_cifs->setEnabled( false );
       }
 
-      TQGroupBox *adv_smbfs = static_cast<TQGroupBox *>( TQT_TQWIDGET(child( "AdvancedSMBFSOptions", "TQGroupBox", true )) );
+      TQGroupBox *adv_smbfs = static_cast<TQGroupBox *>( child( "AdvancedSMBFSOptions", "TQGroupBox", true ) );
 
       if ( adv_smbfs )
       {
         adv_smbfs->setEnabled( true );
       }
 
-      TQLabel *codepage = static_cast<TQLabel *>( TQT_TQWIDGET(child( "CodepageLabel", "TQLabel", true )) );
+      TQLabel *codepage = static_cast<TQLabel *>( child( "CodepageLabel", "TQLabel", true ) );
 
       if ( codepage )
       {
         codepage->setEnabled( true );
       }
 
-      KComboBox *srv_codepage = static_cast<KComboBox *>( TQT_TQWIDGET(child( "kcfg_ServerCodepage", "KComboBox", true )) );
+      KComboBox *srv_codepage = static_cast<KComboBox *>( child( "kcfg_ServerCodepage", "KComboBox", true ) );
 
       if ( srv_codepage )
       {
@@ -643,7 +643,7 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
   if ( item )
   {
     // Enable the input widget:
-    TQWidget *input = static_cast<TQGroupBox *>( TQT_TQWIDGET(child( "CustomInputWidget", "TQGroupBox", true )) );
+    TQWidget *input = static_cast<TQGroupBox *>( child( "CustomInputWidget", "TQGroupBox", true ) );
 
     if ( input )
     {
@@ -651,7 +651,7 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
     }
 
     // Enable/disable the labels, combo boxes, buttons, etc:
-    TQLabel *protocol_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "CustomProtocolLabel", "TQLabel", true )) );
+    TQLabel *protocol_label = static_cast<TQLabel *>( child( "CustomProtocolLabel", "TQLabel", true ) );
 
     if ( protocol_label )
     {
@@ -665,7 +665,7 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
       }
     }
 
-    KComboBox *protocol = static_cast<KComboBox *>( TQT_TQWIDGET(child( "CustomProtocol", "KComboBox", true )) );
+    KComboBox *protocol = static_cast<KComboBox *>( child( "CustomProtocol", "KComboBox", true ) );
 
     if ( protocol )
     {
@@ -683,7 +683,7 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
 
 #ifndef __FreeBSD__
 
-    TQLabel *fs_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "CustomFileSystemLabel", "TQLabel", true )) );
+    TQLabel *fs_label = static_cast<TQLabel *>( child( "CustomFileSystemLabel", "TQLabel", true ) );
 
     if ( fs_label )
     {
@@ -697,7 +697,7 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
       }
     }
 
-    KComboBox *filesystem = static_cast<KComboBox *>( TQT_TQWIDGET(child( "CustomFileSystem", "KComboBox", true )) );
+    KComboBox *filesystem = static_cast<KComboBox *>( child( "CustomFileSystem", "KComboBox", true ) );
 
     if ( filesystem )
     {
@@ -713,7 +713,7 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
       filesystem->setCurrentText( item->text( FileSystem ) );
     }
 
-    TQLabel *write_access_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "CustomWriteAccessLabel", "TQLabel", true )) );
+    TQLabel *write_access_label = static_cast<TQLabel *>( child( "CustomWriteAccessLabel", "TQLabel", true ) );
 
     if ( write_access_label )
     {
@@ -727,7 +727,7 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
       }
     }
 
-    KComboBox *write_access = static_cast<KComboBox *>( TQT_TQWIDGET(child( "CustomWriteAccess", "KComboBox", true )) );
+    KComboBox *write_access = static_cast<KComboBox *>( child( "CustomWriteAccess", "KComboBox", true ) );
 
     if ( write_access )
     {
@@ -745,7 +745,7 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
 
 #endif
 
-    TQLabel *krb_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "CustomKerberosLabel", "TQLabel", true )) );
+    TQLabel *krb_label = static_cast<TQLabel *>( child( "CustomKerberosLabel", "TQLabel", true ) );
 
     if ( krb_label )
     {
@@ -759,7 +759,7 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
       }
     }
 
-    KComboBox *kerberos = static_cast<KComboBox *>( TQT_TQWIDGET(child( "CustomKerberos", "KComboBox", true )) );
+    KComboBox *kerberos = static_cast<KComboBox *>( child( "CustomKerberos", "KComboBox", true ) );
 
     if ( kerberos )
     {
@@ -775,7 +775,7 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
       kerberos->setCurrentText( item->text( Kerberos ) );
     }
 
-    TQLabel *uid_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "CustomUIDLabel", "TQLabel", true )) );
+    TQLabel *uid_label = static_cast<TQLabel *>( child( "CustomUIDLabel", "TQLabel", true ) );
 
     if ( uid_label )
     {
@@ -789,7 +789,7 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
       }
     }
 
-    KLineEdit *uid = static_cast<KLineEdit *>( TQT_TQWIDGET(child( "CustomUID", "KLineEdit", true )) );
+    KLineEdit *uid = static_cast<KLineEdit *>( child( "CustomUID", "KLineEdit", true ) );
 
     if ( uid )
     {
@@ -805,7 +805,7 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
       uid->setText( item->text( UID ) );
     }
 
-    TQLabel *gid_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "CustomGIDLabel", "TQLabel", true )) );
+    TQLabel *gid_label = static_cast<TQLabel *>( child( "CustomGIDLabel", "TQLabel", true ) );
 
     if ( gid_label )
     {
@@ -819,7 +819,7 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
       }
     }
 
-    KLineEdit *gid = static_cast<KLineEdit *>( TQT_TQWIDGET(child( "CustomGID", "KLineEdit", true )) );
+    KLineEdit *gid = static_cast<KLineEdit *>( child( "CustomGID", "KLineEdit", true ) );
 
     if ( gid )
     {
@@ -835,7 +835,7 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
       gid->setText( item->text( GID ) );
     }
 
-    TQLabel *port_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "CustomPortLabel", "TQLabel", true )) );
+    TQLabel *port_label = static_cast<TQLabel *>( child( "CustomPortLabel", "TQLabel", true ) );
 
     if ( port_label )
     {
@@ -849,7 +849,7 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
       }
     }
 
-    KIntNumInput *port = static_cast<KIntNumInput *>( TQT_TQWIDGET(child( "CustomPort", "KIntNumInput", true )) );
+    KIntNumInput *port = static_cast<KIntNumInput *>( child( "CustomPort", "KIntNumInput", true ) );
 
     if ( port )
     {
@@ -865,14 +865,14 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
       port->setValue( item->text( Port ).toInt() );
     }
 
-    KPushButton *remove = static_cast<KPushButton *>( TQT_TQWIDGET(child( "CustomRemoveItem", "KPushButton", true )) );
+    KPushButton *remove = static_cast<KPushButton *>( child( "CustomRemoveItem", "KPushButton", true ) );
 
     if ( remove )
     {
       remove->setEnabled( true );
     }
 
-    KPushButton *remove_all = static_cast<KPushButton *>( TQT_TQWIDGET(child( "CustomRemoveAllItems", "KPushButton", true )) );
+    KPushButton *remove_all = static_cast<KPushButton *>( child( "CustomRemoveAllItems", "KPushButton", true ) );
 
     if ( remove_all )
     {
@@ -882,18 +882,18 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
   else
   {
     // Get the list view:
-    TDEListView *view = static_cast<TDEListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "TDEListView", true )) );
+    TDEListView *view = static_cast<TDEListView *>( child( "CustomOptionsList", "TDEListView", true ) );
 
     if ( view )
     {
-      TQLabel *protocol_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "CustomProtocolLabel", "TQLabel", true )) );
+      TQLabel *protocol_label = static_cast<TQLabel *>( child( "CustomProtocolLabel", "TQLabel", true ) );
 
       if ( protocol_label )
       {
         protocol_label->setEnabled( false );
       }
 
-      KComboBox *protocol = static_cast<KComboBox *>( TQT_TQWIDGET(child( "CustomProtocol", "KComboBox", true )) );
+      KComboBox *protocol = static_cast<KComboBox *>( child( "CustomProtocol", "KComboBox", true ) );
 
       if ( protocol )
       {
@@ -903,14 +903,14 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
 
 #ifndef __FreeBSD__
 
-      TQLabel *fs_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "CustomFileSystemLabel", "TQLabel", true )) );
+      TQLabel *fs_label = static_cast<TQLabel *>( child( "CustomFileSystemLabel", "TQLabel", true ) );
 
       if ( fs_label )
       {
         fs_label->setEnabled( false );
       }
 
-      KComboBox *filesystem = static_cast<KComboBox *>( TQT_TQWIDGET(child( "CustomFileSystem", "KComboBox", true )) );
+      KComboBox *filesystem = static_cast<KComboBox *>( child( "CustomFileSystem", "KComboBox", true ) );
 
       if ( filesystem )
       {
@@ -918,14 +918,14 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
         filesystem->setEnabled( false );
       }
 
-      TQLabel *write_access_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "CustomWriteAccessLabel", "TQLabel", true )) );
+      TQLabel *write_access_label = static_cast<TQLabel *>( child( "CustomWriteAccessLabel", "TQLabel", true ) );
 
       if ( write_access_label )
       {
         write_access_label->setEnabled( false );
       }
 
-      KComboBox *write_access = static_cast<KComboBox *>( TQT_TQWIDGET(child( "CustomWriteAccess", "KComboBox", true )) );
+      KComboBox *write_access = static_cast<KComboBox *>( child( "CustomWriteAccess", "KComboBox", true ) );
 
       if ( write_access )
       {
@@ -935,14 +935,14 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
 
 #endif
 
-      TQLabel *krb_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "CustomKerberosLabel", "TQLabel", true )) );
+      TQLabel *krb_label = static_cast<TQLabel *>( child( "CustomKerberosLabel", "TQLabel", true ) );
 
       if ( krb_label )
       {
         krb_label->setEnabled( false );
       }
 
-      KComboBox *kerberos = static_cast<KComboBox *>( TQT_TQWIDGET(child( "CustomKerberos", "KComboBox", true )) );
+      KComboBox *kerberos = static_cast<KComboBox *>( child( "CustomKerberos", "KComboBox", true ) );
 
       if ( kerberos )
       {
@@ -950,14 +950,14 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
         kerberos->setEnabled( false );
       }
 
-      TQLabel *uid_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "CustomUIDLabel", "TQLabel", true )) );
+      TQLabel *uid_label = static_cast<TQLabel *>( child( "CustomUIDLabel", "TQLabel", true ) );
 
       if ( uid_label )
       {
         uid_label->setEnabled( false );
       }
 
-      KLineEdit *uid = static_cast<KLineEdit *>( TQT_TQWIDGET(child( "CustomUID", "KLineEdit", true )) );
+      KLineEdit *uid = static_cast<KLineEdit *>( child( "CustomUID", "KLineEdit", true ) );
 
       if ( uid )
       {
@@ -965,14 +965,14 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
         uid->setEnabled( false );
       }
 
-      TQLabel *gid_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "CustomGIDLabel", "TQLabel", true )) );
+      TQLabel *gid_label = static_cast<TQLabel *>( child( "CustomGIDLabel", "TQLabel", true ) );
 
       if ( gid_label )
       {
         gid_label->setEnabled( false );
       }
 
-      KLineEdit *gid = static_cast<KLineEdit *>( TQT_TQWIDGET(child( "CustomGID", "KLineEdit", true )) );
+      KLineEdit *gid = static_cast<KLineEdit *>( child( "CustomGID", "KLineEdit", true ) );
 
       if ( gid )
       {
@@ -980,14 +980,14 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
         gid->setEnabled( false );
       }
 
-      TQLabel *port_label = static_cast<TQLabel *>( TQT_TQWIDGET(child( "CustomPortLabel", "TQLabel", true )) );
+      TQLabel *port_label = static_cast<TQLabel *>( child( "CustomPortLabel", "TQLabel", true ) );
 
       if ( port_label )
       {
         port_label->setEnabled( false );
       }
 
-      KIntNumInput *port = static_cast<KIntNumInput *>( TQT_TQWIDGET(child( "CustomPort", "KIntNumInput", true )) );
+      KIntNumInput *port = static_cast<KIntNumInput *>( child( "CustomPort", "KIntNumInput", true ) );
 
       if ( port )
       {
@@ -995,14 +995,14 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
         port->setEnabled( false );
       }
 
-      KPushButton *remove = static_cast<KPushButton *>( TQT_TQWIDGET(child( "CustomRemoveItem", "KPushButton", true )) );
+      KPushButton *remove = static_cast<KPushButton *>( child( "CustomRemoveItem", "KPushButton", true ) );
 
       if ( remove )
       {
         remove->setEnabled( false );
       }
 
-      KPushButton *remove_all = static_cast<KPushButton *>( TQT_TQWIDGET(child( "CustomRemoveAllItems", "KPushButton", true )) );
+      KPushButton *remove_all = static_cast<KPushButton *>( child( "CustomRemoveAllItems", "KPushButton", true ) );
 
       if ( remove_all )
       {
@@ -1015,8 +1015,8 @@ void Smb4KSambaOptions::slotCustomItemClicked( TQListViewItem *item )
 
 void Smb4KSambaOptions::slotCustomProtocolChanged( int index )
 {
-  TDEListView *view =            static_cast<TDEListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "TDEListView", true )) );
-  KComboBox *custom_protocol = static_cast<KComboBox *>( TQT_TQWIDGET(child( "CustomProtocol", "KComboBox", true )) );
+  TDEListView *view =            static_cast<TDEListView *>( child( "CustomOptionsList", "TDEListView", true ) );
+  KComboBox *custom_protocol = static_cast<KComboBox *>( child( "CustomProtocol", "KComboBox", true ) );
 
   if ( view && view->selectedItem() && custom_protocol )
   {
@@ -1043,8 +1043,8 @@ void Smb4KSambaOptions::slotCustomProtocolChanged( int index )
 #ifndef __FreeBSD__
 void Smb4KSambaOptions::slotCustomFileSystemChanged( int index )
 {
-  TDEListView *view =              static_cast<TDEListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "TDEListView", true )) );
-  KComboBox *custom_filesystem = static_cast<KComboBox *>( TQT_TQWIDGET(child( "CustomFileSystem", "KComboBox", true )) );
+  TDEListView *view =              static_cast<TDEListView *>( child( "CustomOptionsList", "TDEListView", true ) );
+  KComboBox *custom_filesystem = static_cast<KComboBox *>( child( "CustomFileSystem", "KComboBox", true ) );
 
   if ( view && view->selectedItem() && custom_filesystem )
   {
@@ -1075,8 +1075,8 @@ void Smb4KSambaOptions::slotCustomFileSystemChanged( int )
 #ifndef __FreeBSD__
 void Smb4KSambaOptions::slotCustomWriteAccessChanged( int index )
 {
-  TDEListView *view =      static_cast<TDEListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "TDEListView", true )) );
-  KComboBox *custom_rw = static_cast<KComboBox *>( TQT_TQWIDGET(child( "CustomWriteAccess", "KComboBox", true )) );
+  TDEListView *view =      static_cast<TDEListView *>( child( "CustomOptionsList", "TDEListView", true ) );
+  KComboBox *custom_rw = static_cast<KComboBox *>( child( "CustomWriteAccess", "KComboBox", true ) );
 
   if ( view && view->selectedItem() && custom_rw )
   {
@@ -1109,8 +1109,8 @@ void Smb4KSambaOptions::slotCustomKerberosChanged( int index )
   // FIXME: Do we need to adjust something here with respect to
   // FreeBSD? It does not know Kerberos for mounting!
 
-  TDEListView *view =            static_cast<TDEListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "TDEListView", true )) );
-  KComboBox *custom_kerberos = static_cast<KComboBox *>( TQT_TQWIDGET(child( "CustomWriteAccess", "KComboBox", true )) );
+  TDEListView *view =            static_cast<TDEListView *>( child( "CustomOptionsList", "TDEListView", true ) );
+  KComboBox *custom_kerberos = static_cast<KComboBox *>( child( "CustomWriteAccess", "KComboBox", true ) );
 
   if ( view && view->selectedItem() && custom_kerberos )
   {
@@ -1136,7 +1136,7 @@ void Smb4KSambaOptions::slotCustomKerberosChanged( int index )
 
 void Smb4KSambaOptions::slotCustomUIDChanged( const TQString &uid )
 {
-  TDEListView *view = static_cast<TDEListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "TDEListView", true )) );
+  TDEListView *view = static_cast<TDEListView *>( child( "CustomOptionsList", "TDEListView", true ) );
 
   if ( view && view->selectedItem() )
   {
@@ -1154,7 +1154,7 @@ void Smb4KSambaOptions::slotCustomUIDChanged( const TQString &uid )
 
 void Smb4KSambaOptions::slotCustomGIDChanged( const TQString &gid )
 {
-  TDEListView *view = static_cast<TDEListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "TDEListView", true )) );
+  TDEListView *view = static_cast<TDEListView *>( child( "CustomOptionsList", "TDEListView", true ) );
 
   if ( view && view->selectedItem() )
   {
@@ -1172,7 +1172,7 @@ void Smb4KSambaOptions::slotCustomGIDChanged( const TQString &gid )
 
 void Smb4KSambaOptions::slotCustomPortChanged( int port )
 {
-  TDEListView *view = static_cast<TDEListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "TDEListView", true )) );
+  TDEListView *view = static_cast<TDEListView *>( child( "CustomOptionsList", "TDEListView", true ) );
 
   if ( view && view->selectedItem() )
   {
@@ -1189,7 +1189,7 @@ void Smb4KSambaOptions::slotCustomPortChanged( int port )
 
 void Smb4KSambaOptions::slotRemoveCustomOption()
 {
-  TDEListView *view = static_cast<TDEListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "TDEListView", true )) );
+  TDEListView *view = static_cast<TDEListView *>( child( "CustomOptionsList", "TDEListView", true ) );
 
   if ( view && view->selectedItem() )
   {
@@ -1208,7 +1208,7 @@ void Smb4KSambaOptions::slotRemoveCustomOption()
 
 void Smb4KSambaOptions::slotRemoveAllCustomOptions()
 {
-  TDEListView *view = static_cast<TDEListView *>( TQT_TQWIDGET(child( "CustomOptionsList", "TDEListView", true )) );
+  TDEListView *view = static_cast<TDEListView *>( child( "CustomOptionsList", "TDEListView", true ) );
 
   if ( view )
   {
