@@ -72,27 +72,27 @@ EditorPage::EditorPage(KTextEditor::Document* pDoc, TQPopupMenu* pMenu,
 	m_pSplit->setResizeMode(m_pCtagsList, TQSplitter::KeepSize);
 	
 	// Perform tasks only when the document has been loaded completely
-	connect(m_pDoc, SIGNAL(completed()), this, SLOT(slotFileOpened()));
+	connect(m_pDoc, TQ_SIGNAL(completed()), this, TQ_SLOT(slotFileOpened()));
 	
 	// Be notified when the text in the editor changes
-	connect(m_pDoc, SIGNAL(textChanged()), this, SLOT(slotSetModified()));
-	connect(m_pDoc, SIGNAL(undoChanged()), this, SLOT(slotUndoChanged()));
+	connect(m_pDoc, TQ_SIGNAL(textChanged()), this, TQ_SLOT(slotSetModified()));
+	connect(m_pDoc, TQ_SIGNAL(undoChanged()), this, TQ_SLOT(slotUndoChanged()));
 	
 	// Store the sizes of the child windows when the tag list is resized
 	// (since it may imply a move of the splitter divider)
-	connect(m_pCtagsList, SIGNAL(resized()), this, SLOT(slotChildResized()));
+	connect(m_pCtagsList, TQ_SIGNAL(resized()), this, TQ_SLOT(slotChildResized()));
 
 	// Go to a symbol's line if it is selected in the tag list
-	connect(m_pCtagsList, SIGNAL(lineRequested(uint)), this,
-		SLOT(slotGotoLine(uint)));
+	connect(m_pCtagsList, TQ_SIGNAL(lineRequested(uint)), this,
+		TQ_SLOT(slotGotoLine(uint)));
 
 	// Add Ctag records to the tag list
-	connect(&m_ctags, SIGNAL(dataReady(FrontendToken*)), m_pCtagsList,
-		SLOT(slotDataReady(FrontendToken*)));
+	connect(&m_ctags, TQ_SIGNAL(dataReady(FrontendToken*)), m_pCtagsList,
+		TQ_SLOT(slotDataReady(FrontendToken*)));
 		
 	// Monitor Ctags' operation
-	connect(&m_ctags, SIGNAL(finished(uint)), m_pCtagsList, 
-		SLOT(slotCtagsFinished(uint)));
+	connect(&m_ctags, TQ_SIGNAL(finished(uint)), m_pCtagsList, 
+		TQ_SLOT(slotCtagsFinished(uint)));
 		
 	// Set the context menu
 	pMenuIf = dynamic_cast<KTextEditor::PopupMenuInterface*>(m_pView);
@@ -102,8 +102,8 @@ EditorPage::EditorPage(KTextEditor::Document* pDoc, TQPopupMenu* pMenu,
 	// Emit a signal whenever the cursor's position changes
 	pCursorIf = dynamic_cast<KTextEditor::ViewCursorInterface*>(m_pView);
 	if (pCursorIf) {
-		connect(m_pView, SIGNAL(cursorPositionChanged()), this,
-			SLOT(slotCursorPosChange()));
+		connect(m_pView, TQ_SIGNAL(cursorPositionChanged()), this,
+			TQ_SLOT(slotCursorPosChange()));
 	}
 }
 
