@@ -74,8 +74,8 @@ SegmentSelector::~SegmentSelector()
 void SegmentSelector::ready()
 {
     m_canvas->viewport()->setCursor(TQt::arrowCursor);
-    connect(m_canvas, TQT_SIGNAL(contentsMoving (int, int)),
-            this, TQT_SLOT(slotCanvasScrolled(int, int)));
+    connect(m_canvas, TQ_SIGNAL(contentsMoving (int, int)),
+            this, TQ_SLOT(slotCanvasScrolled(int, int)));
     setContextHelp(i18n("Click and drag to select segments"));
 }
 
@@ -86,7 +86,7 @@ void SegmentSelector::slotCanvasScrolled(int newX, int newY)
 {
     TQMouseEvent tmpEvent(TQEvent::MouseMove,
                          m_canvas->viewport()->mapFromGlobal(TQCursor::pos()) + TQPoint(newX, newY),
-                         Qt::NoButton, Qt::NoButton);
+                         TQt::NoButton, TQt::NoButton);
     handleMouseMove(&tmpEvent);
 }
 
@@ -172,8 +172,8 @@ SegmentSelector::handleMouseButtonPress(TQMouseEvent *e)
 
         // Add on middle button or ctrl+left - bounding box on rest
         //
-        if (e->button() == Qt::MidButton ||
-            (e->button() == Qt::LeftButton && (e->state() & ControlButton))) {
+        if (e->button() == TQt::MidButton ||
+            (e->button() == TQt::LeftButton && (e->state() & ControlButton))) {
 
             m_dispatchTool = getToolBox()->getTool(SegmentPencil::ToolName);
 
