@@ -200,7 +200,7 @@ void HTMLExporter::exportBasket(Basket *basket, bool isSubBasket)
 	TQFile file(basketFilePath);
 	if (!file.open(IO_WriteOnly))
 		return;
-	stream.setDevice(TQT_TQIODEVICE(&file));
+	stream.setDevice(&file);
 	stream.setEncoding(TQTextStream::UnicodeUTF8);
 
 	// Compute the colors to draw dragient for notes:
