@@ -53,10 +53,10 @@ KNutClient::KNutClient(bool noDock, TQObject* parent, const char *name) : TQObje
   analogRecords = new KNutVarData();
 
   m_upsTimer = new TQTimer (this);
-  connect( m_upsTimer, TQT_SIGNAL(timeout()), TQT_SLOT(slotTimeout()) );
+  connect( m_upsTimer, TQ_SIGNAL(timeout()), TQ_SLOT(slotTimeout()) );
 
   m_reconnectTimer = new TQTimer(this);
-  connect( m_reconnectTimer, TQT_SIGNAL(timeout()), TQT_SLOT(slotReconnectTimeout()) );
+  connect( m_reconnectTimer, TQ_SIGNAL(timeout()), TQ_SLOT(slotReconnectTimeout()) );
 
 
   //  data for combo
@@ -71,16 +71,16 @@ KNutClient::KNutClient(bool noDock, TQObject* parent, const char *name) : TQObje
     m_myDock = new KNutDock(&m_mainUpsInfo,&settingData,upsRecords);
 
     m_myDock->show();
-    connect(m_myDock, TQT_SIGNAL(endApplication()), this, TQT_SLOT(slotExitApplication()));
-    connect(m_myDock, TQT_SIGNAL(activeMainWindow()), this, TQT_SLOT(slotActiveMainWindow()));
-    connect(m_myDock, TQT_SIGNAL(minimize()), this, TQT_SLOT(closeMainWindow()));
-    connect(m_myDock, TQT_SIGNAL(UPSChanged(TQString)), this, TQT_SLOT(slotSetNewUPS (TQString)));
+    connect(m_myDock, TQ_SIGNAL(endApplication()), this, TQ_SLOT(slotExitApplication()));
+    connect(m_myDock, TQ_SIGNAL(activeMainWindow()), this, TQ_SLOT(slotActiveMainWindow()));
+    connect(m_myDock, TQ_SIGNAL(minimize()), this, TQ_SLOT(closeMainWindow()));
+    connect(m_myDock, TQ_SIGNAL(UPSChanged(TQString)), this, TQ_SLOT(slotSetNewUPS (TQString)));
 
-    connect(m_myDock, TQT_SIGNAL(preferences()),this, TQT_SLOT(slotPreferenceUps()));
-    connect(m_myDock, TQT_SIGNAL(printUPSVars()),this, TQT_SLOT(slotPrintUPSVars()));
-    connect(m_myDock, TQT_SIGNAL(instComms()),this, TQT_SLOT(slotInstComms()));
-    connect(m_myDock, TQT_SIGNAL(RWVars()),this, TQT_SLOT(slotRWVars()));
-    connect(m_myDock, TQT_SIGNAL(makeRefreshConnection()),this, TQT_SLOT(slotRefreshConnection()));
+    connect(m_myDock, TQ_SIGNAL(preferences()),this, TQ_SLOT(slotPreferenceUps()));
+    connect(m_myDock, TQ_SIGNAL(printUPSVars()),this, TQ_SLOT(slotPrintUPSVars()));
+    connect(m_myDock, TQ_SIGNAL(instComms()),this, TQ_SLOT(slotInstComms()));
+    connect(m_myDock, TQ_SIGNAL(RWVars()),this, TQ_SLOT(slotRWVars()));
+    connect(m_myDock, TQ_SIGNAL(makeRefreshConnection()),this, TQ_SLOT(slotRefreshConnection()));
     }
 
   addEventString(i18n("Ready."));
@@ -99,11 +99,11 @@ KNutClient::KNutClient(bool noDock, TQObject* parent, const char *name) : TQObje
   m_mainUpsInfo.upsNet = new KNutNet( m_mainUpsInfo.record.upsAddress, m_mainUpsInfo.record.upsName, m_mainUpsInfo.record.port,5,200);
 
 
-  connect(m_mainUpsInfo.upsNet, TQT_SIGNAL(firstConnection(void)),this, TQT_SLOT(slotFirstConnection(void)));
-  connect(m_mainUpsInfo.upsNet, TQT_SIGNAL(connectionError(int)),this, TQT_SLOT(slotErrorConnection(int)));
-  connect(m_mainUpsInfo.upsNet, TQT_SIGNAL(connectionClosed(void )),this, TQT_SLOT(slotConnectionClosed(void)));
-  connect(m_mainUpsInfo.upsNet, TQT_SIGNAL(tryFirstConnection(int )),this, TQT_SLOT(slotTryFirstConnection(int)));
-  connect(m_mainUpsInfo.upsNet, TQT_SIGNAL(tryRepeatFirstConnection(int )),this, TQT_SLOT(slotTryReepatFirstConnection( int )));
+  connect(m_mainUpsInfo.upsNet, TQ_SIGNAL(firstConnection(void)),this, TQ_SLOT(slotFirstConnection(void)));
+  connect(m_mainUpsInfo.upsNet, TQ_SIGNAL(connectionError(int)),this, TQ_SLOT(slotErrorConnection(int)));
+  connect(m_mainUpsInfo.upsNet, TQ_SIGNAL(connectionClosed(void )),this, TQ_SLOT(slotConnectionClosed(void)));
+  connect(m_mainUpsInfo.upsNet, TQ_SIGNAL(tryFirstConnection(int )),this, TQ_SLOT(slotTryFirstConnection(int)));
+  connect(m_mainUpsInfo.upsNet, TQ_SIGNAL(tryRepeatFirstConnection(int )),this, TQ_SLOT(slotTryReepatFirstConnection( int )));
 
 
 // state of connection to usbd, this isn't state of knutnet
@@ -257,7 +257,7 @@ void KNutClient::slotFirstConnection (void) {
   if ((m_mainUpsInfo.upsNet->getState() == KNutNet::Connected) && (!m_mainUpsInfo.errorUpsData)) {
     showStatusEvent();
     // getUpsVars loads informations about variables, but their values too
-    m_upsTimer->start( m_mainUpsInfo.record.delay, TRUE ); // nastartujeme casovac - starts timer
+    m_upsTimer->start( m_mainUpsInfo.record.delay, true ); // nastartujeme casovac - starts timer
     }
   }
 
@@ -282,7 +282,7 @@ void KNutClient::slotErrorConnection (int error) {
     if (m_mainUpsInfo.reconnectCount > countNextConnDelay) m_mainUpsInfo.reconnectCount = countNextConnDelay;
 
     addEventString(i18n("The connection failed. The next connection will make after %1 sec.").arg(nextConnDelay[m_mainUpsInfo.reconnectCount-1]),m_mainUpsInfo.record.name);
-    m_reconnectTimer->start( nextConnDelay[m_mainUpsInfo.reconnectCount-1]*1000, TRUE ); // starts reconnect timer again
+    m_reconnectTimer->start( nextConnDelay[m_mainUpsInfo.reconnectCount-1]*1000, true ); // starts reconnect timer again
     }
   else {
 //tqDebug ("KNutClient::slotErrorConnection (3)");
@@ -335,9 +335,9 @@ void KNutClient::initVars (void) {
   KNutUpsData::upsRecordDef upsData; // structure includes informations about UPS // struktura obsahuje udaje o UPS
   TQFont appFont = kapp->font(); // systemovy font pri startu
   kapp->config()->setGroup ("");
-  settingData.areYouSure=kapp->config()->readBoolEntry("AreYouSure",FALSE);
+  settingData.areYouSure=kapp->config()->readBoolEntry("AreYouSure",false);
 
-  int helpInt=kapp->config()->readNumEntry("UseMainWindow",TRUE);
+  int helpInt=kapp->config()->readNumEntry("UseMainWindow",1);
 
 //std::cout << "readNumEntry " <<  helpInt << "--" << std::endl;
   switch (helpInt) {
@@ -347,27 +347,27 @@ void KNutClient::initVars (void) {
     }
 
 
-  settingData.useMessageWindow=kapp->config()->readBoolEntry("UseMessageWindow",FALSE);
-  settingData.activatedMainWindow=kapp->config()->readBoolEntry("PreviousMainWindow",FALSE);
+  settingData.useMessageWindow=kapp->config()->readBoolEntry("UseMessageWindow",false);
+  settingData.activatedMainWindow=kapp->config()->readBoolEntry("PreviousMainWindow",false);
   settingData.x=kapp->config()->readNumEntry("PosX",0);
   settingData.y=kapp->config()->readNumEntry("PosY",0);
   settingData.width=kapp->config()->readNumEntry("Width",300);
   settingData.height=kapp->config()->readNumEntry("Height",200);
-  settingData.useDescription=kapp->config()->readBoolEntry("UseDescription",FALSE);
+  settingData.useDescription=kapp->config()->readBoolEntry("UseDescription",false);
   settingData.countCols=kapp->config()->readNumEntry("NumberOfCols",knc::DefaultCountCols);
   settingData.panelFlags=kapp->config()->readUnsignedNumEntry("PanelFlags",KNutFrontPanel::DefaultPanelFlags);
   settingData.inputFrequency=kapp->config()->readNumEntry("InputFrequency",knc::DefaultInputFrequency);
   settingData.inputVoltage=kapp->config()->readNumEntry("InputVoltage",knc::DefaultInputVoltage);
-  settingData.lowHighXfer=kapp->config()->readBoolEntry("LowHighXfer",FALSE);
-  settingData.customFont=kapp->config()->readBoolEntry("CustomFont",FALSE);
+  settingData.lowHighXfer=kapp->config()->readBoolEntry("LowHighXfer",false);
+  settingData.customFont=kapp->config()->readBoolEntry("CustomFont",false);
   settingData.aPanelFont=kapp->config()->readFontEntry("AnalogPanelFont",&appFont);
   settingData.mPanelFont=kapp->config()->readFontEntry("MainPanelFont",&appFont);
   int upsCount=kapp->config()->readNumEntry("NumberOfUpsRecords",0);
-  settingData.customBColor=kapp->config()->readBoolEntry("CustomBColor",FALSE);
+  settingData.customBColor=kapp->config()->readBoolEntry("CustomBColor",false);
   settingData.mainBackgroundColor=kapp->config()->readColorEntry ("MainBackGroundColor",& DEFAULT_BG_COLOR);
-  settingData.customBPanelColor=kapp->config()->readBoolEntry("CustomBPanelColor",FALSE);
-  settingData.customBAnalogColor=kapp->config()->readBoolEntry("CustomBAnalogColor",FALSE);
-  settingData.customOAnalogColor=kapp->config()->readBoolEntry("CustomOAnalogColor",FALSE);
+  settingData.customBPanelColor=kapp->config()->readBoolEntry("CustomBPanelColor",false);
+  settingData.customBAnalogColor=kapp->config()->readBoolEntry("CustomBAnalogColor",false);
+  settingData.customOAnalogColor=kapp->config()->readBoolEntry("CustomOAnalogColor",false);
   settingData.mPanelBackgroundColor=kapp->config()->readColorEntry ("MPanelBackGroundColor",& DEFAULT_BG_COLOR);
   settingData.aPanelBackgroundColor=kapp->config()->readColorEntry ("APanelBackGroundColor",& DEFAULT_BG_COLOR);
   settingData.analogFingerColor=kapp->config()->readColorEntry ("AnalogFingerColor",& DEFAULT_FINGER_COLOR);
@@ -377,7 +377,7 @@ void KNutClient::initVars (void) {
   settingData.analogScaleColor=kapp->config()->readColorEntry ("AnalogScaleColor",& DEFAULT_SCALE_COLOR);
   settingData.analogFontColor=kapp->config()->readColorEntry ("AnalogFontColor",& DEFAULT_FONT_COLOR);
   settingData.toolTipFlags=kapp->config()->readUnsignedNumEntry("ToolTipFlags",KNutDock::DefaultToolTipFlags);
-  settingData.customTDEIconColor=kapp->config()->readBoolEntry("CustomTDEIconColor",FALSE);
+  settingData.customTDEIconColor=kapp->config()->readBoolEntry("CustomTDEIconColor",false);
   settingData.kIconBackgroundColor=kapp->config()->readColorEntry ("TDEIconBackGroundColor",& DEFAULT_KICON_COLOR);
   settingData.typeOfTDEIcon=kapp->config()->readBoolEntry("TypeOfTDEIcon", KNutDock::pictureKI);
   settingData.typeDigitalProcessing=kapp->config()->readNumEntry("DigitalProcessingOfPointers", 2);
@@ -756,7 +756,7 @@ void KNutClient::slotTimeout (void) {
     if (m_myDock) m_myDock->clearDockValues();
     }
   if (m_myDock) m_myDock->repaintDock();
-  m_upsTimer->start( m_mainUpsInfo.record.delay, TRUE ); // nastartujem znovu
+  m_upsTimer->start( m_mainUpsInfo.record.delay, true ); // nastartujem znovu
   }
 
 
@@ -784,7 +784,7 @@ void KNutClient::slotConnectionClosed(void) {
 
   m_mainUpsInfo.reconnecting = true;
   m_mainUpsInfo.reconnectCount = 1;
-  m_reconnectTimer->start( nextConnDelay[0]*1000, TRUE ); // start timer for reconnect delay
+  m_reconnectTimer->start( nextConnDelay[0]*1000, true ); // start timer for reconnect delay
   }
 
 void KNutClient::showStatusEvent(void) {
@@ -925,7 +925,7 @@ void KNutClient::slotSetNewUPS (TQString name) {
 void KNutClient::slotPreferenceUps (void) {
 
   KNutPrefDlg* prefDlg = new KNutPrefDlg ( upsRecords, analogRecords, &settingData, m_mainUpsInfo.record.name ); // aktivujeme dialog pro preference
-  connect (prefDlg,TQT_SIGNAL(signalChangeConfig(unsigned int)),this,TQT_SLOT(slotSetConfig(unsigned int)));
+  connect (prefDlg,TQ_SIGNAL(signalChangeConfig(unsigned int)),this,TQ_SLOT(slotSetConfig(unsigned int)));
   prefDlg->exec();
   delete prefDlg;
   }
@@ -987,7 +987,7 @@ void KNutClient::slotSetConfig (unsigned int changeSetting) {
       m_mainUpsInfo.upsNet->open();
 //      if ((mainUpsInfo.upsNet->getState() == KNutNet::Connected) && (!mainUpsInfo.errorUpsData)) {
 //        showStatusEvent();
-//        upsTimer->start( mainUpsInfo.record.delay, TRUE ); // nastartujeme casovac
+//        upsTimer->start( mainUpsInfo.record.delay, true ); // nastartujeme casovac
 //        }
       }
 
@@ -1065,7 +1065,7 @@ void KNutClient::slotRWVars(void) {
     if (!m_mainUpsInfo.errorUpsData) {
       if (m_mainUpsInfo.upsNet->readNumberVars (KNutNet::RWVars)) {
         KNutRWVar *windowRWVars = new KNutRWVar(&m_mainUpsInfo.name,&m_mainUpsInfo.password,m_mainUpsInfo.record.userName,m_mainUpsInfo.record.password,m_mainUpsInfo.upsNet);
-        connect (windowRWVars,TQT_SIGNAL(signalChangeRWVars(TQString)),this,TQT_SLOT(slotChangeRWVars(TQString)));
+        connect (windowRWVars,TQ_SIGNAL(signalChangeRWVars(TQString)),this,TQ_SLOT(slotChangeRWVars(TQString)));
         if (windowRWVars->upsOk())  windowRWVars->exec();
         delete windowRWVars;
        }
@@ -1152,19 +1152,19 @@ void KNutClient::exitMainWindow (void) {
 void KNutClient::makeMainWindow (void) {
 
   mainWindow = new KNutMainWindow(m_listKNutEvent ,&m_mainUpsInfo, &settingData, upsRecords, analogRecords);
-  connect(mainWindow, TQT_SIGNAL(UPSChanged (TQString)), this, TQT_SLOT(slotSetNewUPS (TQString)));
-  connect(mainWindow, TQT_SIGNAL(preferenceUps()),this, TQT_SLOT(slotPreferenceUps()));
-  connect(mainWindow, TQT_SIGNAL(showUPSVars()),this, TQT_SLOT(slotPrintUPSVars()));
-  connect(mainWindow, TQT_SIGNAL(makeInstComms()),this, TQT_SLOT(slotInstComms()));
-  connect(mainWindow, TQT_SIGNAL(makeRWVars()),this, TQT_SLOT(slotRWVars()));
-  connect(mainWindow, TQT_SIGNAL(makeRefreshConnection()),this, TQT_SLOT(slotRefreshConnection()));
-  connect(mainWindow, TQT_SIGNAL(saveConf()),this, TQT_SLOT(slotSaveConf()));
+  connect(mainWindow, TQ_SIGNAL(UPSChanged (TQString)), this, TQ_SLOT(slotSetNewUPS (TQString)));
+  connect(mainWindow, TQ_SIGNAL(preferenceUps()),this, TQ_SLOT(slotPreferenceUps()));
+  connect(mainWindow, TQ_SIGNAL(showUPSVars()),this, TQ_SLOT(slotPrintUPSVars()));
+  connect(mainWindow, TQ_SIGNAL(makeInstComms()),this, TQ_SLOT(slotInstComms()));
+  connect(mainWindow, TQ_SIGNAL(makeRWVars()),this, TQ_SLOT(slotRWVars()));
+  connect(mainWindow, TQ_SIGNAL(makeRefreshConnection()),this, TQ_SLOT(slotRefreshConnection()));
+  connect(mainWindow, TQ_SIGNAL(saveConf()),this, TQ_SLOT(slotSaveConf()));
 
 
 
 
-  connect(mainWindow, TQT_SIGNAL(endApplication()), this, TQT_SLOT(slotExitApplication()));
-  connect(mainWindow, TQT_SIGNAL(destroyed()), this, TQT_SLOT(exitMainWindow()));
+  connect(mainWindow, TQ_SIGNAL(endApplication()), this, TQ_SLOT(slotExitApplication()));
+  connect(mainWindow, TQ_SIGNAL(destroyed()), this, TQ_SLOT(exitMainWindow()));
   }
 
 
@@ -1180,7 +1180,7 @@ void KNutClient::slotActiveMainWindow (void) {
       getUpsData();
       makeMainWindow();
       if (m_myDock) m_myDock->repaintDock(m_mainUpsInfo.netError);
-      m_upsTimer->start( 1, TRUE ); // nastartujem znovu
+      m_upsTimer->start( 1, true ); // nastartujem znovu
       // 1 proto aby se zpracovali pripadne udalosti o zruseni spojeni
       }
     else {
@@ -1210,7 +1210,7 @@ void KNutClient::closeMainWindow (void) {
     m_upsTimer->stop();
     mainWindow->close();
     mainWindow=0;
-    m_upsTimer->start( 1, TRUE ); // starts timer // nastartujeme casovac
+    m_upsTimer->start( 1, true ); // starts timer // nastartujeme casovac
     }
   }
 
@@ -1220,7 +1220,7 @@ void KNutClient::slotExitApplication(void) {
   m_upsTimer->stop();
   if (mainWindow) {
     // odpojime protoze exitMainWindow by byl vykonan az po zkonceni procedury;
-    disconnect(mainWindow, TQT_SIGNAL(destroyed()), this, TQT_SLOT(exitMainWindow()));
+    disconnect(mainWindow, TQ_SIGNAL(destroyed()), this, TQ_SLOT(exitMainWindow()));
     delete mainWindow;
     mainWindow = 0;
     }
