@@ -52,7 +52,7 @@
 	
 	#ifdef COMPILE_TDE_SUPPORT
 		#include <tdeconfig.h>
-		#include <kstddirs.h>
+		#include <kstandarddirs.h>
 	#endif
 
 #else
