@@ -2943,7 +2943,7 @@ channel
 			Console
 		@description:
 			Triggered when a [cmd]http.get[/cmd] file download has terminated execution.
-			If the transfer has been succesfull then $0 will contain the value 1 (true),
+			If the transfer has been succesfull then $0 will contain the value true,
 			otherwise will contain the value 0. $1 contains the remote url and $2 the local
 			path on disk of the saved file. $3 contains the magic identifier passed to
 			the http.get command by the means of the -i switch.
