@@ -78,7 +78,7 @@ KDockWidget *MainWindow::createDock(const TQString &name, const TQPixmap &icon,
   ddata.position = position;
   ddata.dock = dock;
   ddata.action = new ViewMenuAction(dock);
-  connect(ddata.action, TQT_SIGNAL(activated(TQWidget *)), TQT_SLOT(toggleToolView(TQWidget *)));
+  connect(ddata.action, TQ_SIGNAL(activated(TQWidget *)), TQ_SLOT(toggleToolView(TQWidget *)));
   _docks += ddata;
   initDockPosition(ddata);
   return dock;
@@ -100,13 +100,13 @@ MainWindow::MainWindow()
     _editorStatus = new TQLabel(statusBar());
     statusBar()->addWidget(_editorStatus, 0, true);
     _programmerStatus = new ProgrammerStatusWidget(statusBar());
-    connect(_programmerStatus, TQT_SIGNAL(configure()), TQT_SLOT(configureProgrammer()));
-    connect(_programmerStatus, TQT_SIGNAL(selected(const Programmer::Group &)), TQT_SLOT(selectProgrammer(const Programmer::Group &)));
+    connect(_programmerStatus, TQ_SIGNAL(configure()), TQ_SLOT(configureProgrammer()));
+    connect(_programmerStatus, TQ_SIGNAL(selected(const Programmer::Group &)), TQ_SLOT(selectProgrammer(const Programmer::Group &)));
     statusBar()->addWidget(_programmerStatus->widget(), 0, true);
     _toolStatus = new ToolStatusWidget(statusBar());
-    connect(_toolStatus, TQT_SIGNAL(configureToolchain()), TQT_SLOT(configureToolchains()));
-    connect(_toolStatus, TQT_SIGNAL(configure()), TQT_SLOT(configureProject()));
-    connect(_toolStatus, TQT_SIGNAL(selected(const Tool::Group &)), TQT_SLOT(selectTool(const Tool::Group &)));
+    connect(_toolStatus, TQ_SIGNAL(configureToolchain()), TQ_SLOT(configureToolchains()));
+    connect(_toolStatus, TQ_SIGNAL(configure()), TQ_SLOT(configureProject()));
+    connect(_toolStatus, TQ_SIGNAL(selected(const Tool::Group &)), TQ_SLOT(selectTool(const Tool::Group &)));
     statusBar()->addWidget(_toolStatus->widget(), 0, true);
 
 // interface
@@ -120,7 +120,7 @@ MainWindow::MainWindow()
     KDockWidget *dock = createDock("project_manager_dock_widget", PURL::icon(PURL::Project),
                                    i18n("Project Manager"), DockPosition(KDockWidget::DockLeft, 20));
     Main::_projectManager = new ProjectManager::View(dock);
-    connect(TQT_TQOBJECT(Main::_projectManager), TQT_SIGNAL(guiChanged()), TQT_SLOT(updateGUI()));
+    connect(Main::_projectManager, TQ_SIGNAL(guiChanged()), TQ_SLOT(updateGUI()));
     dock->setWidget(Main::_projectManager);
 
     dock = createDock("watch_view_dock_widget", loader.loadIcon("viewmag", TDEIcon::Small),
@@ -130,9 +130,9 @@ MainWindow::MainWindow()
 
     Main::_editorManager = new EditorManager(_mainDock);
     _mainDock->setWidget(Main::_editorManager);
-    connect(TQT_TQOBJECT(Main::_editorManager), TQT_SIGNAL(guiChanged()), TQT_SLOT(updateGUI()));
-    connect(TQT_TQOBJECT(Main::_editorManager), TQT_SIGNAL(modified(const PURL::Url &)), TQT_TQOBJECT(Main::_projectManager), TQT_SLOT(modified(const PURL::Url &)));
-    connect(TQT_TQOBJECT(Main::_editorManager), TQT_SIGNAL(statusChanged(const TQString &)), _editorStatus, TQT_SLOT(setText(const TQString &)));
+    connect(Main::_editorManager, TQ_SIGNAL(guiChanged()), TQ_SLOT(updateGUI()));
+    connect(Main::_editorManager, TQ_SIGNAL(modified(const PURL::Url &)), Main::_projectManager, TQ_SLOT(modified(const PURL::Url &)));
+    connect(Main::_editorManager, TQ_SIGNAL(statusChanged(const TQString &)), _editorStatus, TQ_SLOT(setText(const TQString &)));
 
     dock = createDock("compile_log_dock_widget", loader.loadIcon("piklab_compile", TDEIcon::Small),
                       i18n("Compile Log"), DockPosition(KDockWidget::DockBottom, 80));
@@ -158,65 +158,65 @@ MainWindow::MainWindow()
     dock->setWidget(Main::_consoleView);
 
 // managers
-    Programmer::manager = new Programmer::GuiManager(TQT_TQOBJECT(this));
+    Programmer::manager = new Programmer::GuiManager(this);
     Programmer::manager->setView(_programLog);
-    connect(Programmer::manager, TQT_SIGNAL(actionMessage(const TQString &)), _actionStatus, TQT_SLOT(setText(const TQString &)));
-    connect(Programmer::manager, TQT_SIGNAL(showProgress(bool)), TQT_SLOT(showProgress(bool)));
-    connect(Programmer::manager, TQT_SIGNAL(setTotalProgress(uint)), TQT_SLOT(setTotalProgress(uint)));
-    connect(Programmer::manager, TQT_SIGNAL(setProgress(uint)), TQT_SLOT(setProgress(uint)));
+    connect(Programmer::manager, TQ_SIGNAL(actionMessage(const TQString &)), _actionStatus, TQ_SLOT(setText(const TQString &)));
+    connect(Programmer::manager, TQ_SIGNAL(showProgress(bool)), TQ_SLOT(showProgress(bool)));
+    connect(Programmer::manager, TQ_SIGNAL(setTotalProgress(uint)), TQ_SLOT(setTotalProgress(uint)));
+    connect(Programmer::manager, TQ_SIGNAL(setProgress(uint)), TQ_SLOT(setProgress(uint)));
 
     Debugger::manager = new Debugger::GuiManager;
-    connect(Debugger::manager, TQT_SIGNAL(targetStateChanged()), TQT_SLOT(updateGUI()));
-    connect(Debugger::manager, TQT_SIGNAL(statusChanged(const TQString &)), _debugStatus, TQT_SLOT(setText(const TQString &)));
-    connect(Debugger::manager, TQT_SIGNAL(actionMessage(const TQString &)), _actionStatus, TQT_SLOT(setText(const TQString &)));
+    connect(Debugger::manager, TQ_SIGNAL(targetStateChanged()), TQ_SLOT(updateGUI()));
+    connect(Debugger::manager, TQ_SIGNAL(statusChanged(const TQString &)), _debugStatus, TQ_SLOT(setText(const TQString &)));
+    connect(Debugger::manager, TQ_SIGNAL(actionMessage(const TQString &)), _actionStatus, TQ_SLOT(setText(const TQString &)));
 
-    Main::_compileManager = new Compile::Manager(TQT_TQOBJECT(this));
+    Main::_compileManager = new Compile::Manager(this);
     Main::_compileManager->setView(Main::_compileLog);
-    connect(Main::_compileManager, TQT_SIGNAL(success()), TQT_SLOT(compileSuccess()));
-    connect(Main::_compileManager, TQT_SIGNAL(failure()), TQT_SLOT(compileFailure()));
-    connect(Main::_compileManager, TQT_SIGNAL(updateFile(const Compile::FileData &)),
-            TQT_SLOT(updateFile(const Compile::FileData &)));
+    connect(Main::_compileManager, TQ_SIGNAL(success()), TQ_SLOT(compileSuccess()));
+    connect(Main::_compileManager, TQ_SIGNAL(failure()), TQ_SLOT(compileFailure()));
+    connect(Main::_compileManager, TQ_SIGNAL(updateFile(const Compile::FileData &)),
+            TQ_SLOT(updateFile(const Compile::FileData &)));
 
 // actions
     // file actions
-    TDEAction *a = KStdAction::openNew(TQT_TQOBJECT(this), TQT_SLOT(newSourceFile()), actionCollection());
+    TDEAction *a = KStdAction::openNew(this, TQ_SLOT(newSourceFile()), actionCollection());
     a->setText(i18n("&New Source File..."));
-    (void)new TDEAction(i18n("New hex File..."), "document-new", 0, TQT_TQOBJECT(this), TQT_SLOT(newHexFile()),
+    (void)new TDEAction(i18n("New hex File..."), "document-new", 0, this, TQ_SLOT(newHexFile()),
                       actionCollection(), "file_new_hex");
-    KStdAction::open(TQT_TQOBJECT(this), TQT_SLOT(openFile()), actionCollection());
-    TDERecentFilesAction *recent = KStdAction::openRecent(TQT_TQOBJECT(this), TQT_SLOT(openRecentFile(const KURL &)), actionCollection());
+    KStdAction::open(this, TQ_SLOT(openFile()), actionCollection());
+    TDERecentFilesAction *recent = KStdAction::openRecent(this, TQ_SLOT(openRecentFile(const KURL &)), actionCollection());
     recent->setMaxItems(20);
     recent->loadEntries(kapp->config(), "recent-files");
-    (void)new TDEAction(i18n("Save All"), 0, 0, TQT_TQOBJECT(Main::_editorManager), TQT_SLOT(saveAllFiles()),
+    (void)new TDEAction(i18n("Save All"), 0, 0, Main::_editorManager, TQ_SLOT(saveAllFiles()),
                       actionCollection(), "file_save_all");
-    KStdAction::close(TQT_TQOBJECT(Main::_editorManager), TQT_SLOT(closeCurrentEditor()), actionCollection());
-    (void)new TDEAction(i18n("C&lose All"), 0, 0, TQT_TQOBJECT(Main::_editorManager), TQT_SLOT(closeAllEditors()),
+    KStdAction::close(Main::_editorManager, TQ_SLOT(closeCurrentEditor()), actionCollection());
+    (void)new TDEAction(i18n("C&lose All"), 0, 0, Main::_editorManager, TQ_SLOT(closeAllEditors()),
                       actionCollection(), "file_close_all");
-    (void)new TDEAction(i18n("Close All Others"), 0, 0, TQT_TQOBJECT(Main::_editorManager), TQT_SLOT(closeAllOtherEditors()),
+    (void)new TDEAction(i18n("Close All Others"), 0, 0, Main::_editorManager, TQ_SLOT(closeAllOtherEditors()),
                       actionCollection(), "file_closeother");
-    KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(close()), actionCollection());
+    KStdAction::quit(this, TQ_SLOT(close()), actionCollection());
 
     // edit actions
 
     // view actions
     (void)new TDEAction(i18n("Back"), "back", TQt::ALT + TQt::Key_Left,
-                      TQT_TQOBJECT(Main::_editorManager), TQT_SLOT(goBack()), actionCollection(), "history_back");
+                      Main::_editorManager, TQ_SLOT(goBack()), actionCollection(), "history_back");
     (void)new TDEAction(i18n("Forward"), "forward", TQt::ALT + TQt::Key_Right,
-                      TQT_TQOBJECT(Main::_editorManager), TQT_SLOT(goForward()), actionCollection(), "history_forward");
+                      Main::_editorManager, TQ_SLOT(goForward()), actionCollection(), "history_forward");
     (void)new TDEAction(i18n("Switch to..."), 0, TQt::CTRL + TQt::Key_Slash,
-                      TQT_TQOBJECT(Main::_editorManager), TQT_SLOT(switchToEditor()), actionCollection(), "file_switchto");
+                      Main::_editorManager, TQ_SLOT(switchToEditor()), actionCollection(), "file_switchto");
     (void)new TDEAction(i18n("Switch Header/Implementation"), 0, TQt::SHIFT + TQt::Key_F12,
-                      TQT_TQOBJECT(Main::_editorManager), TQT_SLOT(switchHeaderImplementation()), actionCollection(), "view_switch_source");
+                      Main::_editorManager, TQ_SLOT(switchHeaderImplementation()), actionCollection(), "view_switch_source");
     (void)new TDEAction(TQString(), 0, 0,
-                      Debugger::manager, TQT_SLOT(toggleBreakpoint()), actionCollection(), "toggle_breakpoint");
+                      Debugger::manager, TQ_SLOT(toggleBreakpoint()), actionCollection(), "toggle_breakpoint");
     (void)new TDEAction(TQString(), 0, 0,
-                      Debugger::manager, TQT_SLOT(toggleEnableBreakpoint()), actionCollection(), "enable_breakpoint");
+                      Debugger::manager, TQ_SLOT(toggleEnableBreakpoint()), actionCollection(), "enable_breakpoint");
     (void)new TDEAction(i18n("Show disassembly location"), 0, 0,
-                      Debugger::manager, TQT_SLOT(showDisassemblyLocation()), actionCollection(), "show_disassembly_location");
+                      Debugger::manager, TQ_SLOT(showDisassemblyLocation()), actionCollection(), "show_disassembly_location");
     TDEActionMenu *toolViewsMenu = new TDEActionMenu( i18n("Tool Views"), 0, "view_tool_views");
-    connect(toolViewsMenu->popupMenu(), TQT_SIGNAL(aboutToShow()), TQT_SLOT(updateToolViewsActions()));
+    connect(toolViewsMenu->popupMenu(), TQ_SIGNAL(aboutToShow()), TQ_SLOT(updateToolViewsActions()));
     actionCollection()->insert(toolViewsMenu);
-    a = new TDEAction(i18n("&Reset Layout"), 0, 0, TQT_TQOBJECT(this), TQT_SLOT(resetDockLayout()), actionCollection(), "view_reset_layout");
+    a = new TDEAction(i18n("&Reset Layout"), 0, 0, this, TQ_SLOT(resetDockLayout()), actionCollection(), "view_reset_layout");
     toolViewsMenu->insert(a);
     toolViewsMenu->popupMenu()->insertSeparator();
     TQValueList<DockData>::iterator it;
@@ -224,106 +224,106 @@ MainWindow::MainWindow()
 
     // project actions
     (void)new TDEAction(i18n("New Project..."), "piklab_createproject", 0,
-                      TQT_TQOBJECT(this), TQT_SLOT(newProject()), actionCollection(), "project_new");
+                      this, TQ_SLOT(newProject()), actionCollection(), "project_new");
     (void)new TDEAction(i18n("Open Project..."), "piklab_openproject", 0,
-                      TQT_TQOBJECT(this), TQT_SLOT(openProject()), actionCollection(), "project_open");
+                      this, TQ_SLOT(openProject()), actionCollection(), "project_open");
     recent = new TDERecentFilesAction(i18n("Open Recent Project"), 0,
-                      TQT_TQOBJECT(this), TQT_SLOT(openRecentProject(const KURL &)), actionCollection(), "project_open_recent");
+                      this, TQ_SLOT(openRecentProject(const KURL &)), actionCollection(), "project_open_recent");
     recent->setMaxItems(20);
     recent->loadEntries(kapp->config(), "recent-projects");
     (void)new TDEAction(i18n("Project Options..."), "configure", 0,
-                      TQT_TQOBJECT(this), TQT_SLOT(configureProject()), actionCollection(), "project_options");
+                      this, TQ_SLOT(configureProject()), actionCollection(), "project_options");
     (void)new TDEAction(i18n("Close Project"), "window-close", 0,
-                      TQT_TQOBJECT(this), TQT_SLOT(closeProject()), actionCollection(), "project_close");
+                      this, TQ_SLOT(closeProject()), actionCollection(), "project_close");
     (void)new TDEAction(i18n("Add Source File..."), "piklab_addfile", 0,
-                      TQT_TQOBJECT(Main::_projectManager), TQT_SLOT(insertSourceFiles()), actionCollection(), "project_add_source_file");
+                      Main::_projectManager, TQ_SLOT(insertSourceFiles()), actionCollection(), "project_add_source_file");
     (void)new TDEAction(i18n("Add Object File..."), "piklab_addfile", 0,
-                      TQT_TQOBJECT(Main::_projectManager), TQT_SLOT(insertObjectFiles()), actionCollection(), "project_add_object_file");
+                      Main::_projectManager, TQ_SLOT(insertObjectFiles()), actionCollection(), "project_add_object_file");
     (void)new TDEAction(i18n("Add Current File"), "piklab_addcurrentfile", 0,
-                      TQT_TQOBJECT(Main::_projectManager), TQT_SLOT(insertCurrentFile()), actionCollection(), "project_add_current_file");
+                      Main::_projectManager, TQ_SLOT(insertCurrentFile()), actionCollection(), "project_add_current_file");
 
     // build actions
     (void)new TDEAction(i18n("&Build Project"), "piklab_compile", TQt::Key_F8,
-                      TQT_TQOBJECT(this), TQT_SLOT(buildProject()), actionCollection(), "build_build_project");
+                      this, TQ_SLOT(buildProject()), actionCollection(), "build_build_project");
     (void)new TDEAction(i18n("&Compile File"), 0, TQt::SHIFT + TQt::Key_F8,
-                      TQT_TQOBJECT(this), TQT_SLOT(compileFile()), actionCollection(), "build_compile_file");
+                      this, TQ_SLOT(compileFile()), actionCollection(), "build_compile_file");
     (void)new TDEAction(i18n("Clean"), "trashcan_empty", 0,
-                      TQT_TQOBJECT(this), TQT_SLOT(cleanBuild()), actionCollection(), "build_clean");
+                      this, TQ_SLOT(cleanBuild()), actionCollection(), "build_clean");
     (void)new TDEAction(i18n("Stop"), "process-stop", 0,
-                      TQT_TQOBJECT(this), TQT_SLOT(stopBuild()), actionCollection(), "build_stop");
+                      this, TQ_SLOT(stopBuild()), actionCollection(), "build_stop");
 
     // programmer actions
     (void)new TDEAction(i18n("&Connect"), "connect_creating", 0,
-                      Programmer::manager, TQT_SLOT(connectDevice()), actionCollection(), "prog_connect");
+                      Programmer::manager, TQ_SLOT(connectDevice()), actionCollection(), "prog_connect");
     (void)new TDEToggleAction(i18n("Device Power"), "piklab_power", 0,
-                            Programmer::manager, TQT_SLOT(toggleDevicePower()), actionCollection(), "prog_power");
+                            Programmer::manager, TQ_SLOT(toggleDevicePower()), actionCollection(), "prog_power");
     (void)new TDEAction(i18n("&Disconnect"), "connect_no", 0,
-                      Programmer::manager, TQT_SLOT(disconnectDevice()), actionCollection(), "prog_disconnect");
+                      Programmer::manager, TQ_SLOT(disconnectDevice()), actionCollection(), "prog_disconnect");
     (void)new TDEAction(i18n("&Program"), "piklab_burnchip", TQt::SHIFT + TQt::Key_F5,
-                      TQT_TQOBJECT(this), TQT_SLOT(program()), actionCollection(), "prog_program");
+                      this, TQ_SLOT(program()), actionCollection(), "prog_program");
     (void)new TDEAction(i18n("&Verify"), "piklab_verifychip", TQt::SHIFT + TQt::Key_F6,
-                      TQT_TQOBJECT(this), TQT_SLOT(verify()), actionCollection(), "prog_verify");
+                      this, TQ_SLOT(verify()), actionCollection(), "prog_verify");
     (void)new TDEAction(i18n("&Read"), "piklab_readchip", TQt::SHIFT + TQt::Key_F7,
-                      TQT_TQOBJECT(this), TQT_SLOT(read()), actionCollection(), "prog_read");
+                      this, TQ_SLOT(read()), actionCollection(), "prog_read");
     (void)new TDEAction(i18n("&Erase"), "piklab_erasechip", 0,
-                      TQT_TQOBJECT(this), TQT_SLOT(erase()), actionCollection(), "prog_erase");
+                      this, TQ_SLOT(erase()), actionCollection(), "prog_erase");
     (void)new TDEAction(i18n("&Blank Check"), "piklab_blankcheck", 0,
-                      TQT_TQOBJECT(this), TQT_SLOT(blankCheck()), actionCollection(), "prog_blank_check");
+                      this, TQ_SLOT(blankCheck()), actionCollection(), "prog_blank_check");
     (void)new TDEAction(i18n("&Run"), "launch", TQt::SHIFT + TQt::Key_F9,
-                      Programmer::manager, TQT_SLOT(run()), actionCollection(), "prog_run");
+                      Programmer::manager, TQ_SLOT(run()), actionCollection(), "prog_run");
     (void)new TDEAction(i18n("&Stop"), "piklab_stop", 0,
-                      Programmer::manager, TQT_SLOT(halt()), actionCollection(), "prog_stop");
+                      Programmer::manager, TQ_SLOT(halt()), actionCollection(), "prog_stop");
     (void)new TDEAction(i18n("R&estart"), "piklab_restart", 0,
-                      Programmer::manager, TQT_SLOT(restart()), actionCollection(), "prog_restart");
+                      Programmer::manager, TQ_SLOT(restart()), actionCollection(), "prog_restart");
     (void)new TDEAction(i18n("&Advanced..."), 0, 0,
-                      Programmer::manager , TQT_SLOT(showAdvancedDialog()), actionCollection(), "prog_advanced");
+                      Programmer::manager , TQ_SLOT(showAdvancedDialog()), actionCollection(), "prog_advanced");
     (void)new TDEAction(i18n("Settings..."), "configure", 0,
-                      TQT_TQOBJECT(this), TQT_SLOT(showProgrammerSettings()), actionCollection(), "prog_settings");
+                      this, TQ_SLOT(showProgrammerSettings()), actionCollection(), "prog_settings");
 
     // debugger actions
     (void)new TDEAction(i18n("&Start"), "launch", TQt::SHIFT + TQt::Key_F9,
-                      Programmer::manager, TQT_SLOT(restart()), actionCollection(), "debug_start");
+                      Programmer::manager, TQ_SLOT(restart()), actionCollection(), "debug_start");
     (void)new TDEAction(i18n("&Run"), "piklab_run", TQt::SHIFT + TQt::Key_F9,
-                      Programmer::manager, TQT_SLOT(run()), actionCollection(), "debug_run");
+                      Programmer::manager, TQ_SLOT(run()), actionCollection(), "debug_run");
     (void)new TDEAction(i18n("&Step"), "piklab_debug_step", 0,
-                      Programmer::manager, TQT_SLOT(step()), actionCollection(), "debug_next");
+                      Programmer::manager, TQ_SLOT(step()), actionCollection(), "debug_next");
     //(void)new TDEAction(i18n("Step &In"), "piklab_debug_stepin",
-    //             0, TQT_TQOBJECT(this), TQT_SLOT(debugStepIn()), actionCollection(), "debug_step_in");
+    //             0, this, TQ_SLOT(debugStepIn()), actionCollection(), "debug_step_in");
     //(void)new TDEAction(i18n("Step &Out"), "piklab_debug_stepout",
-    //             0, TQT_TQOBJECT(this), TQT_SLOT(debugStepOut()), actionCollection(), "debug_step_out");
+    //             0, this, TQ_SLOT(debugStepOut()), actionCollection(), "debug_step_out");
     (void)new TDEAction(i18n("&Break<Translators: it is the verb>", "&Halt"), "piklab_debughalt", 0,
-                      Programmer::manager, TQT_SLOT(halt()), actionCollection(), "debug_halt");
+                      Programmer::manager, TQ_SLOT(halt()), actionCollection(), "debug_halt");
     (void)new TDEAction(i18n("&Disconnect/Stop"), "piklab_stop", 0,
-                      Programmer::manager, TQT_SLOT(disconnectDevice()), actionCollection(), "debug_stop");
+                      Programmer::manager, TQ_SLOT(disconnectDevice()), actionCollection(), "debug_stop");
     (void)new TDEAction(i18n("R&eset"), "piklab_restart", 0,
-                      Programmer::manager, TQT_SLOT(restart()), actionCollection(), "debug_reset");
+                      Programmer::manager, TQ_SLOT(restart()), actionCollection(), "debug_reset");
     (void)new TDEAction(i18n("Show Program Counter"), "piklab_program_counter", 0,
-                      Debugger::manager, TQT_SLOT(showPC()), actionCollection(), "debug_show_pc");
+                      Debugger::manager, TQ_SLOT(showPC()), actionCollection(), "debug_show_pc");
     (void)new TDEAction(i18n("Clear All Breakpoints"), "remove", 0,
-                      Debugger::manager, TQT_SLOT(clearBreakpoints()), actionCollection(), "debug_clear_breakpoints");
+                      Debugger::manager, TQ_SLOT(clearBreakpoints()), actionCollection(), "debug_clear_breakpoints");
     (void)new TDEAction(i18n("Settings..."), "configure", 0,
-                      TQT_TQOBJECT(this), TQT_SLOT(showDebuggerSettings()), actionCollection(), "debug_settings");
+                      this, TQ_SLOT(showDebuggerSettings()), actionCollection(), "debug_settings");
 
     // tools
     (void)new TDEAction(i18n("&Pikloops..."), 0, 0,
-                      TQT_TQOBJECT(this), TQT_SLOT(runPikloops()), actionCollection(), "tools_pikloops");
+                      this, TQ_SLOT(runPikloops()), actionCollection(), "tools_pikloops");
     (void)new TDEAction(i18n("&Find Files..."), "edit-find", 0,
-                      TQT_TQOBJECT(this), TQT_SLOT(runKfind()), actionCollection(), "tools_kfind");
+                      this, TQ_SLOT(runKfind()), actionCollection(), "tools_kfind");
     (void)new TDEAction(i18n("&Device Information..."), "application-vnd.tde.info", 0,
-                      TQT_TQOBJECT(this), TQT_SLOT(showDeviceInfo()), actionCollection(), "tools_device_information");
+                      this, TQ_SLOT(showDeviceInfo()), actionCollection(), "tools_device_information");
     (void)new TDEAction(i18n("&Config Generator..."), 0, 0,
-                      TQT_TQOBJECT(this), TQT_SLOT(configGenerator()), actionCollection(), "tools_config_generator");
+                      this, TQ_SLOT(configGenerator()), actionCollection(), "tools_config_generator");
     (void)new TDEAction(i18n("&Template Generator..."), 0, 0,
-                      TQT_TQOBJECT(this), TQT_SLOT(templateGenerator()), actionCollection(), "tools_template_generator");
+                      this, TQ_SLOT(templateGenerator()), actionCollection(), "tools_template_generator");
 
     // settings actions
     (void)new TDEAction(i18n("Configure Toolchains..."), 0, 0,
-                      TQT_TQOBJECT(this), TQT_SLOT(configureToolchains()), actionCollection(), "options_configure_toolchains");
-    (void)KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(configure()), actionCollection());
+                      this, TQ_SLOT(configureToolchains()), actionCollection(), "options_configure_toolchains");
+    (void)KStdAction::preferences(this, TQ_SLOT(configure()), actionCollection());
 
     // help
     (void)new TDEAction(i18n("Report Bug..."), "likeback_bug", 0,
-                      TQT_TQOBJECT(LikeBack::instance()), TQT_SLOT(iFoundABug()), actionCollection(), "help_report_bug_piklab");
+                      LikeBack::instance(), TQ_SLOT(iFoundABug()), actionCollection(), "help_report_bug_piklab");
 
     setupGUI();
     readDockConfig();
@@ -332,25 +332,25 @@ MainWindow::MainWindow()
     menuBar()->insertItem(new TQLabel(menuBar())); // #### first widget is put left-most...
     MenuBarButton *button = new MenuBarButton("likeback_like", menuBar());
     TQToolTip::add(button, i18n("I like..."));
-    connect(button, TQT_SIGNAL(clicked()), TQT_TQOBJECT(LikeBack::instance()), TQT_SLOT(iLike()));
+    connect(button, TQ_SIGNAL(clicked()), LikeBack::instance(), TQ_SLOT(iLike()));
     menuBar()->insertItem(button);
     button = new MenuBarButton("likeback_dislike", menuBar());
     TQToolTip::add(button, i18n("I do not like..."));
-    connect(button, TQT_SIGNAL(clicked()), TQT_TQOBJECT(LikeBack::instance()), TQT_SLOT(iDoNotLike()));
+    connect(button, TQ_SIGNAL(clicked()), LikeBack::instance(), TQ_SLOT(iDoNotLike()));
     menuBar()->insertItem(button);
     button = new MenuBarButton("likeback_bug", menuBar());
     TQToolTip::add(button, i18n("I found a bug..."));
-    connect(button, TQT_SIGNAL(clicked()), TQT_TQOBJECT(LikeBack::instance()), TQT_SLOT(iFoundABug()));
+    connect(button, TQ_SIGNAL(clicked()), LikeBack::instance(), TQ_SLOT(iFoundABug()));
     menuBar()->insertItem(button);
     button = new MenuBarButton("configure", menuBar());
     TQToolTip::add(button, i18n("Configure email..."));
-    connect(button, TQT_SIGNAL(clicked()), TQT_TQOBJECT(LikeBack::instance()), TQT_SLOT(askEMail()));
+    connect(button, TQ_SIGNAL(clicked()), LikeBack::instance(), TQ_SLOT(askEMail()));
     menuBar()->insertItem(button);
     button = new MenuBarButton("help", menuBar());
-    connect(button, TQT_SIGNAL(clicked()), TQT_TQOBJECT(LikeBack::instance()), TQT_SLOT(showWhatsThisMessage()));
+    connect(button, TQ_SIGNAL(clicked()), LikeBack::instance(), TQ_SLOT(showWhatsThisMessage()));
     menuBar()->insertItem(button);
 
-    TQTimer::singleShot(0, TQT_TQOBJECT(this), TQT_SLOT(initialLoading()));
+    TQTimer::singleShot(0, this, TQ_SLOT(initialLoading()));
 }
 
 MainWindow::~MainWindow()
@@ -404,7 +404,7 @@ void MainWindow::configureToolbar()
 {
   saveMainWindowSettings(TDEGlobal::config(), "MainWindow");
   KEditToolbar dlg(actionCollection());
-  connect(&dlg, TQT_SIGNAL(newToolbarConfig()), TQT_SLOT(applyToolbarSettings()));
+  connect(&dlg, TQ_SIGNAL(newToolbarConfig()), TQ_SLOT(applyToolbarSettings()));
   dlg.exec();
 }
 
@@ -710,7 +710,7 @@ void MainWindow::runKfind()
   PURL::Url url = Main::projectManager().projectUrl();
   if ( !url.isEmpty() ) path = url.path();
   _kfindProcess->setup("kfind", path, false);
-  connect(_kfindProcess, TQT_SIGNAL(done(int)), TQT_SLOT(kfindDone()));
+  connect(_kfindProcess, TQ_SIGNAL(done(int)), TQ_SLOT(kfindDone()));
   if ( !_kfindProcess->start(0) )
     MessageBox::sorry(i18n("Could not run \"kfind\""), Log::Show);
 }
@@ -726,7 +726,7 @@ void MainWindow::runPikloops()
   if (_pikloopsProcess) return;
   _pikloopsProcess = new ::Process::StringOutput;
   _pikloopsProcess->setup("pikloops", TQStringList(), false);
-  connect(_pikloopsProcess, TQT_SIGNAL(done(int)), TQT_SLOT(pikloopsDone()));
+  connect(_pikloopsProcess, TQ_SIGNAL(done(int)), TQ_SLOT(pikloopsDone()));
   if ( !_pikloopsProcess->start(0) )
     MessageBox::detailedSorry(i18n("Could not run \"pikloops\""), i18n("The Pikloops utility (%1) is not installed in your system.").arg("http://pikloops.sourceforge.net"), Log::Show);
 }
@@ -991,3 +991,5 @@ void MainWindow::setProgress(uint nb)
   _actionProgress->setProgress(nb);
   TQApplication::eventLoop()->processEvents(TQEventLoop::ExcludeUserInput); // #### DANGER !!!!
 }
+
+#include "toplevel.moc"
