@@ -911,7 +911,7 @@ ProjectManager::ProjectManager( KTechlab * ktl, KateMDI::ToolView * parent )
 	setListCaption( i18n("File") );
 	setCaption( i18n("Project Manager") );
 	
-	connect( this, TQT_SIGNAL(clicked(TQListViewItem*)), this, TQT_SLOT(slotItemClicked(TQListViewItem*)) );
+	connect( this, TQ_SIGNAL(clicked(TQListViewItem*)), this, TQ_SLOT(slotItemClicked(TQListViewItem*)) );
 }
 
 
