@@ -94,13 +94,13 @@ TextFileImportDialog::TextFileImportDialog(TQWidget *parent)
 	m_customSeparator = new TQTextEdit(indentedTextEdit);
 	m_customSeparator->setTextFormat(TQt::PlainText);
 	hLayout->addWidget(m_customSeparator);
-	m_choices->insertChild(TQT_TQOBJECT(indentedTextEdit));
+	m_choices->insertChild(indentedTextEdit);
 
 	new TQRadioButton(i18n("&All in one note"),                  m_choices);
 	m_choices->setButton(0);
 	topLayout->addWidget(m_choices);
 
-	connect( m_customSeparator, TQT_SIGNAL(textChanged()), this, TQT_SLOT(customSeparatorChanged()) );
+	connect( m_customSeparator, TQ_SIGNAL(textChanged()), this, TQ_SLOT(customSeparatorChanged()) );
 
 	setMainWidget(page);
 }
