@@ -121,7 +121,7 @@ bool HTMLExporter::exec() {
   if(options() & ExportProgress) {
     ProgressItem& item = ProgressManager::self()->newProgressItem(this, TQString(), true);
     item.setTotalSteps(100);
-    connect(&item, TQT_SIGNAL(signalCancelled(ProgressItem*)), TQT_SLOT(slotCancel()));
+    connect(&item, TQ_SIGNAL(signalCancelled(ProgressItem*)), TQ_SLOT(slotCancel()));
   }
   // ok if not ExportProgress, no worries
   ProgressItem::Done done(this);
@@ -466,7 +466,7 @@ TQWidget* HTMLExporter::widget(TQWidget* parent_, const char* name_/*=0*/) {
   m_widget = new TQWidget(parent_, name_);
   TQVBoxLayout* l = new TQVBoxLayout(m_widget);
 
-  TQGroupBox* box = new TQGroupBox(1, Qt::Horizontal, i18n("HTML Options"), m_widget);
+  TQGroupBox* box = new TQGroupBox(1, TQt::Horizontal, i18n("HTML Options"), m_widget);
   l->addWidget(box);
 
   m_checkPrintHeaders = new TQCheckBox(i18n("Print field headers"), box);
